.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP OPERATOR CLASS" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP OPERATOR CLASS \- ユーザ定義演算子クラスの削除
.SH SYNOPSIS
.sp
.nf
DROP OPERATOR CLASS \fIname\fR USING \fIaccess_method\fR [ CASCADE | RESTRICT ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
既存の演算子クラスの名前 (スキーマ修飾名でも可)。
.TP
\fB\fIaccess_method\fB\fR
この演算子クラスを使用するインデックスアクセスメソッドの名前です。
.TP
\fBCASCADE\fR
この演算子クラスに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、その演算子の削除を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP OPERATOR CLASS\fR
コマンドが正常に実行された場合に返されるメッセージです。
.PP
.SH "説明"
.PP
\fBDROP OPERATOR CLASS\fR を実行すると、データベースから既存の演算子クラスを削除できます。 このコマンドを実行するには、演算子クラスの所有者でなければなりません。
.SS "注釈"
.PP
\fBDROP OPERATOR CLASS\fR 文は PostgreSQL の言語拡張です。
.PP
演算子クラスの作成方法に関する情報については CREATE OPERATOR CLASS [\fBcreate_operator_class\fR(l)] を参照して下さい。
.SH "使用方法"
.PP
B-tree 演算子クラス widget_ops を削除します。
.sp
.nf
DROP OPERATOR CLASS widget_ops USING btree;
   
.sp
.fi
この演算子クラスを使用する既存のインデックスが存在する場合には、このコマンドは実行できません。 このようなインデックスを演算子クラスとともに削除するには、CASCADE を追加します。
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には、\fBDROP OPERATOR CLASS\fR はありません。
