.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP TRIGGER" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP TRIGGER \- トリガの削除
.SH SYNOPSIS
.sp
.nf
DROP TRIGGER \fIname\fR ON \fItable\fR [ CASCADE | RESTRICT ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
既存のトリガの名前です。
.TP
\fB\fItable\fB\fR
テーブルの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
このトリガに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、このトリガの削除を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP TRIGGER\fR
トリガの削除に成功すると返されるメッセージです。
.TP
\fBERROR: DropTrigger: there is no trigger \fIname\fB on relation "\fItable\fB"\fR
このメッセージは、指定したトリガが存在しない場合に返されます。
.PP
.SH "説明"
.PP
\fBDROP TRIGGER\fR は既存のトリガ定義を削除します。 このコマンドを実行するユーザは、トリガが定義されたテーブルの所有者でなければなりません。
.SH "例"
.PP
テーブル films にあるトリガ if_dist_exists を削除するには以下のようにします。
.sp
.nf
DROP TRIGGER if_dist_exists ON films;
.sp
.fi
.SH "互換性"
.TP
\fBSQL92\fR
SQL92 には \fBDROP TRIGGER\fR 文はありません。
.TP
\fBSQL99\fR
PostgreSQL の \fBDROP TRIGGER\fR 文は、SQL99 とは互換性がありません。 SQL99 ではトリガ名はテーブルに局所的なものではありませんので、このコマンドは単に DROP TRIGGER \fIname\fR となります。
.SH "関連項目"
CREATE TRIGGER [\fBcreate_trigger\fR(l)]
