.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "COMMIT" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
COMMIT \- 現在のトランザクションのコミット
.SH SYNOPSIS
.sp
.nf
COMMIT [ WORK | TRANSACTION ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
省略可能なキーワードです。何も影響はありません。
.PP
.SS "出力"
.PP
.TP
\fBCOMMIT\fR
トランザクションのコミットに成功すると返されるメッセージです。
.TP
\fBWARNING: COMMIT: no transaction in progress\fR
処理中のトランザクションがない場合です。
.PP
.SH "説明"
.PP
\fBCOMMIT\fR は現在のトランザクションをコミットします。そのトランザクションで行われたすべての変更は他のユーザに見えるようになり、クラッシュが起きても一貫性が保証されます。
.SS "注釈"
.PP
キーワード WORK と TRANSACTION は意味がなく、省略可能です。
.PP
トランザクションを中止するには    ROLLBACK   [\fBrollback\fR(l)]を使用して下さい。
.SH "使用方法"
.PP
すべての変更を永続化するには以下のようにします。
.sp
.nf
COMMIT WORK;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 は COMMIT と COMMIT WORK という2つの形式のみを規定しています。その他の点は完全な互換性があります。
