.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP CONVERSION" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP CONVERSION \- ユーザ定義変換の削除
.SH SYNOPSIS
.sp
.nf
DROP CONVERSION \fIconversion_name\fR
    [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP CONVERSION\fR を使用すると、以前に定義した変換を削除できます。
.PP
変換を削除可能にするには、その変換を所有している必要があります。
"パラメータ"
.TP
\fB\fIconversion_name\fB\fR
変換の名前です。 変換名は、スキーマ修飾することもできます。
.TP
\fBCASCADE\fR
.TP
\fBRESTRICT\fR
これらのキーワードを指定しても、変換に対する依存関係がないため、効果はありません。
.SH "注釈"
.PP
ユーザ定義の変換を作成するには、\fBCREATE CONVERSION\fR を使用します。
.PP
変換を削除するのに必要な権限は、今後リリースされるバージョンで変更される可能性があります。
.SH "例"
.PP
myname という名前の変換を削除するには、以下のようにします。
.sp
.nf
DROP CONVERSION myname;
.sp
.fi
.SH "互換性"
.PP
\fBDROP CONVERSION\fR は、PostgreSQL の拡張です。 SQL99 には、\fBDROP CONVERSION\fR 文はありません。
.SH "関連項目"
.PP
CREATE CONVERSION [\fBcreate_conversion\fR(l)]
