.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE SCHEMA" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE SCHEMA \- 新しいスキーマを定義
.SH SYNOPSIS
.sp
.nf
CREATE SCHEMA \fIschemaname\fR [ AUTHORIZATION \fIusername\fR ] [ \fIschema_element\fR [ ... ] ]
CREATE SCHEMA AUTHORIZATION \fIusername\fR [ \fIschema_element\fR [ ... ] ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIschemaname\fB\fR
作成するスキーマの名前です。 省略された場合、ユーザ名がスキーマ名として使用されます。
.TP
\fB\fIusername\fB\fR
スキーマを所有するユーザの名前です。 省略された場合、デフォルトでこのコマンドを実行したユーザになります。 自分以外のユーザを所有者とするスキーマを作成できるのは、スーパーユーザだけです。
.TP
\fB\fIschema_element\fB\fR
そのスキーマ内で作成されるオブジェクトを定義する SQL文です。 現在、\fBCREATE SCHEMA\fR 内では、\fBCREATE TABLE\fR、\fBCREATE VIEW\fR、および \fBGRANT\fR のみが句として使用可能です。 他の種類のオブジェクトは、スキーマ作成後に個別のコマンドで作成できます。
.PP
.SS "出力"
.PP
.TP
\fBCREATE SCHEMA\fR
コマンドに成功した場合に返されるメッセージです。
.TP
\fBERROR: namespace "\fIschemaname\fB" already exists\fR
指定したスキーマがすでに存在している場合のメッセージです。
.PP
.SH "説明"
.PP
\fBCREATE SCHEMA\fR を実行すると、現在のデータベースに新しいスキーマを登録します。 スキーマ名は、現在のデータベースにある既存のスキーマとは異なる名前にする必要があります。
.PP
スキーマは、本質的には名前空間です。 スキーマには、名前付きオブジェクト (テーブル、データ型、関数、および演算子) が含まれます。これらのオブジェクトの名前は、他のスキーマに存在する他のオブジェクト名と重複してもかまいません。 名前付きオブジェクトには、スキーマ名を接頭語としてオブジェクト名を「修飾」するか、あるいは必要なスキーマを含んだ検索パスを設定することによって、アクセスできます。
.PP
オプションで、\fBCREATE SCHEMA\fR には、新しいスキーマ内でオブジェクトを作成するためのサブコマンドを付加することができます。 サブコマンドは、本質的にはスキーマ作成後に発行される別コマンドと同じように扱われます。ただし、AUTHORIZATION 句が使用されている場合に、作成されたすべてのオブジェクトの所有者が指定したユーザになるという点で異なっています。
.SS "注釈"
.PP
スキーマを作成するには、呼び出すユーザが、現在のデータベースでの CREATE 権限を持っている必要があります。 (もちろん、スーパーユーザにはこの制限はありません。)
.PP
スキーマを削除するには、\fBDROP SCHEMA\fR を使用してください。
.SH "例"
.PP
スキーマを作成するには、次のようにします。
.sp
.nf
CREATE SCHEMA myschema;
  
.sp
.fi
.PP
ユーザ joe にスキーマを作成するには、次のようにします。スキーマ名も joe とします。
.sp
.nf
CREATE SCHEMA AUTHORIZATION joe;
  
.sp
.fi
.PP
スキーマを作成し、テーブルおよびビューもそのスキーマ内に作成するには、次のようにします。
.sp
.nf
CREATE SCHEMA hollywood
    CREATE TABLE films (title text, release date, awards text[])
    CREATE VIEW winners AS
        SELECT title, release FROM films WHERE awards IS NOT NULL;
  
.sp
.fi
個々のサブコマンドの最後にセミコロンがないことに注意してください。
.PP
以下の例では、上記と同じ結果を得る方法を示しています。
.sp
.nf
CREATE SCHEMA hollywood;
CREATE TABLE hollywood.films (title text, release date, awards text[]);
CREATE VIEW hollywood.winners AS
    SELECT title, release FROM hollywood.films WHERE awards IS NOT NULL;
  
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 では、\fBCREATE SCHEMA\fR で DEFAULT CHARACTER SET 句を使用できます。同様に、現在 PostgreSQL で使用できるよりも多くのサブコマンドを使用できます。
.PP
SQL92 では、\fBCREATE SCHEMA\fR のサブコマンドを任意の順序で記述できます。 現在の PostgreSQL の実装では、サブコマンドでの下方参照ができない場合があります。そのため、下方参照を避けるために、サブコマンドの順序を並べ替える必要が生じる可能性もあります。
.PP
SQL92 では、スキーマの所有者は、常にそのスキーマ内のすべてのオブジェクトを所有しています。 PostgreSQL では、スキーマ所有者以外のユーザが所有するオブジェクトを、スキーマに含めることができます。 このような状態は、スキーマ所有者が、自分のスキーマでの CREATE 権限を他のユーザに与えた場合にのみ発生します。
