.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "FETCH" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
FETCH \- カーソルを使用してテーブルから行を取り出す
.SH SYNOPSIS
.sp
.nf
FETCH [ \fIdirection\fR ] [ \fIcount\fR ] { IN | FROM } \fIcursor\fR
FETCH [ FORWARD | BACKWARD | RELATIVE ] [ \fI#\fR | ALL | NEXT | PRIOR ] 
    { IN | FROM } \fIcursor\fR

  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIdirection\fB\fR
\fIselector\fR は行を取り出す方向を定義します。次のうちの 1 つを使用できます。
.RS
.TP
\fBFORWARD\fR
後方の行を取り出します。これは、\fIselector\fR が省略された場合のデフォルト値です。
.TP
\fBBACKWARD\fR
前方の行を取り出します。
.TP
\fBRELATIVE\fR
SQL92 との互換性のためだけの余分な単語です。
.RE
.PP
.TP
\fB\fIcount\fB\fR
\fIcount\fR は何行取り出すのかを決定します。次のうちの 1 つを使用できます。
.RS
.TP
\fB\fI#\fB\fR
取り出す行数の指定を行なう符号付き整数です。負の整数値は FORWARD と BACKWARD の意味を切替えることと同じであることに注意して下さい。
.TP
\fBALL\fR
残っている全ての行を取り出します。
.TP
\fBNEXT\fR
引数 count に \fB1\fR を指定することと同じです。
.TP
\fBPRIOR\fR
引数 count に \fB-1\fR を指定することと同じです。
.RE
.PP
.TP
\fB\fIcursor\fB\fR
開いているカーソルの名前です。
.PP
.SS "出力"
.PP
\fBFETCH\fR は指定カーソルによって定義された問い合わせの結果を返します。問い合わせが失敗した場合には次のメッセージが返されます。
.TP
\fBWARNING: PerformPortalFetch:portal "\fIcursor\fB" not found\fR
\fIカーソル\fR が事前に宣言されていない場合です。カーソルはトランザクションブロック内で宣言されなければなりません。
.TP
\fBWARNING: FETCH/ABSOLUTE not supported, using RELATIVE\fR
PostgreSQL はカーソルの絶対位置指定をサポートしていません。
.TP
\fBERROR: FETCH/RELATIVE at current position is not supported\fR
SQL92 では、以下の構文を使ってカーソルの``現在位置''から繰り返しデータを取り出すことができます。
.sp
.nf
FETCH RELATIVE 0 FROM \fIcursor\fR.
	
.sp
.fi

PostgreSQL では、現在この記述方法を サポートしていません。 実際ゼロという値は全ての行を取り出さなければならないことを示すものとして予約されており、ALL キーワードを指定したことと同じことになります。RELATIVE キーワードが使用された場合、PostgreSQLは、そのユーザが SQL92 の振舞いを意図したものと見なし、エラーメッセージを返します。
.PP
.SH "説明"
.PP
\fBFETCH\fR によりユーザはカーソルを使って行を取得することができます。取得される行数は \fI#\fR で指定されます。もしカーソルに残る行数が \fI#\fRより少ない場合、有効な行だけが取り出されます。行数の代わりとして ALL キーワードで代用すると、カーソルの残りの行全てが取り出されます。FORWARD（前方）にもBACKWARD（後方）にもインスタンスを取り出すことができます。デフォルトの方向は FORWARD です。
.sp
.RS
.B "Tip:"
負の値も行数の指定に使用することができます。負の値は FORWARD キーワードと BACKWARD キーワードの意味を逆にすることと同じです。例えば、\fBFORWARD -1\fR は \fBBACKWARD 1\fR と同じになります。 
.RE
.sp
.SS "注釈"
.PP
FORWARD と BACKWARD キーワードは PostgreSQL の言語拡張であることに注意して下さい。また、SQL92構文も、このコマンドの 2 番目の形式として指定したものでサポートされています。詳細については後述の互換性に関する論点を参照して下さい。
.PP
通常、カーソルでの更新をどのように元にしたテーブルに戻すかを決定することは、VIEW での更新の場合と同様にできませんので、カーソル内のデータの更新は PostgreSQL でサポートされていません。データを入れ換えるには、明示的に UPDATE コマンドを発行する必要があります。
.PP
カーソルが保存しているデータは複数のユーザの問い合わせでも使わ れますので、カーソルはトランザクションの内側でのみ使用できます。
.PP
カーソルの位置を変えるためには    MOVE   [\fBmove\fR(l)] を使用して下さい。DECLARE [\fBdeclare\fR(l)] はカーソルを定義します。トランザクションに関する更に詳しい情報はBEGIN [\fBbegin\fR(l)]、   COMMIT   [\fBcommit\fR(l)]および   ROLLBACK   [\fBrollback\fR(l)]を参照して下さい。
.SH "使用方法"
.PP
以下の例はカーソルを使ってテーブル内を行き来する列です。
.sp
.nf
カーソルを設定し使用します。

BEGIN WORK;
DECLARE liahona CURSOR FOR SELECT * FROM films;

-- カーソル liahona から最初の5行を取り出します。
FETCH FORWARD 5 IN liahona;

 code  |          title          | did | date_prod  |  kind    | len
-------+-------------------------+-----+------------+----------+-------
 BL101 | The Third Man           | 101 | 1949-12-23 | Drama    | 01:44
 BL102 | The African Queen       | 101 | 1951-08-11 | Romantic | 01:43
 JL201 | Une Femme est une Femme | 102 | 1961-03-12 | Romantic | 01:25
 P_301 | Vertigo                 | 103 | 1958-11-14 | Action   | 02:08
 P_302 | Becket                  | 103 | 1964-02-03 | Drama    | 02:28

--前の行を取り出します。
FETCH BACKWARD 1 IN liahona;

 code  | title   | did | date_prod  | kind   | len
-------+---------+-----+------------+--------+-------
 P_301 | Vertigo | 103 | 1958-11-14 | Action | 02:08

-- カーソルを閉じコミットします。

CLOSE liahona;
COMMIT WORK;
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
.sp
.RS
.B "Note:"
カーソルの非埋め込み使用は PostgreSQLの拡張です。カーソルの構文と使用は SQL92で定義される埋め込み形式のカーソルと比較されています。
.RE
.sp
.PP
SQL92 は FETCH のカーソルの絶対位置を指定することができます。 また、結果を明示的な変数に入れることができます。
.sp
.nf
FETCH ABSOLUTE \fI#\fR
    FROM \fIcursor\fR
    INTO :\fIvariable\fR [, ...]
    
.sp
.fi
.TP
\fBABSOLUTE\fR
カーソルは特定の絶対行番号に位置されるべきです。すべてのPostgreSQL 行番号は相対的な数ですのでこの機能はサポートされていません。
.TP
\fB:\fIvariable\fB\fR
目的のホスト変数です。
.PP
