.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "MOVE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
MOVE \- テーブルの指定された行へカーソルを移動
.SH SYNOPSIS
.sp
.nf
MOVE [ \fIdirection\fR ] [ \fIcount\fR ] 
    { IN | FROM } \fIcursor\fR
  
.sp
.fi
.SH "説明"
.PP
\fBMOVE\fR によってユーザがカーソルの位置を指定した行数だけ動かすことが可能です。\fBMOVE\fR は\fBFETCH\fR コマンドと同じように動作しますが、カーソルを移動するだけで行は返しません。
.PP
構文と使用方法についての詳細はFETCH [\fBfetch\fR(l)]を参照してください。
.SS "注釈"
.PP
\fBMOVE\fR は PostgreSQL の言語拡張です。
.PP
有効な引数の説明はFETCH [\fBfetch\fR(l)]を参照してください。カーソルの定義はDECLARE [\fBdeclare\fR(l)]を参照してください。トランザクションの詳細はBEGIN [\fBbegin\fR(l)]、    COMMIT   [\fBcommit\fR(l)]、そして   ROLLBACK   [\fBrollback\fR(l)]を参照してください。
.SH "使用方法"
.PP
カーソルを設定し使用します。
.sp
.nf
BEGIN WORK;
DECLARE liahona CURSOR  FOR SELECT * FROM films;
-- 最初の5行を飛ばします
MOVE FORWARD 5 IN liahona;
MOVE
-- liahona カーソル内の 6行目を抽出します。
FETCH 1 IN liahona;
FETCH

 code  | title  | did | date_prod | kind   | len
-------+--------+-----+-----------+--------+-------
 P_303 | 48 Hrs | 103 | 1982-10-22| Action | 01:37
(1 row)
-- liahona カーソルを閉じ、作業をコミットします。
CLOSE liahona;
COMMIT WORK;
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には \fBMOVE\fR 文はありません。代わりに SQL92 は、暗黙的にカーソルを正しい位置に移動しカーソルの絶対位置から\fBFETCH\fR をすることができます。 
