.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP LANGUAGE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP LANGUAGE \- ユーザ定義の手続き言語の削除
.SH SYNOPSIS
.sp
.nf
DROP [ PROCEDURAL ] LANGUAGE \fIname\fR [ CASCADE | RESTRICT ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
既存の手続き言語の名前です。後方互換のため、この名前を単一引用符で括ることもできます。
.TP
\fBCASCADE\fR
その言語に依存するオブジェクト (その言語で記述している関数など) を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、その言語の削除要求を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP LANGUAGE\fR
このメッセージは言語の削除に成功した場合に返されます。
.TP
\fBERROR: Language "\fIname\fB" doesn't exist\fR
このメッセージは、\fIname\fR で呼び出される関数がデータベースで検出できない場合に出力されます。
.PP
.SH "説明"
.PP
\fBDROP PROCEDURAL LANGUAGE\fR を実行すると、\fIname\fR という名前で登録されていた手続き言語の定義を削除します。
.SS "注釈"
.PP
\fBDROP PROCEDURAL LANGUAGE\fR 文は、PostgreSQL の言語拡張です。
.PP
手続き言語の作成方法に関する情報については、CREATE LANGUAGE [\fBcreate_language\fR(l)] を参照して下さい。
.SH "使用方法"
.PP
下記のコマンドを実行すると、PL/Sample 言語を削除することができます。
.sp
.nf
DROP LANGUAGE plsample;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には、\fBDROP PROCEDURAL LANGUAGE\fR はありません。
