.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP AGGREGATE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP AGGREGATE \- ユーザ定義の集約関数の削除
.SH SYNOPSIS
.sp
.nf
DROP AGGREGATE \fIname\fR ( \fItype\fR ) [ CASCADE | RESTRICT ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
既存の集約関数の名前です (スキーマ修飾名でも可)。
.TP
\fB\fItype\fB\fR
集約関数の入力データ型を指定します。または、関数が任意のデータ型の入力を受け付ける場合は、* を指定します。(データ型についての、詳細については \fIPostgreSQLユーザガイド\fRを参照して下さい。) [Comment: ここには、章番号を直接書き込むのではなく、相互参照するような形式にしてください。]
.TP
\fBCASCADE\fR
その集約に依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、その集約の削除要求を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP AGGREGATE\fR
コマンドに成功した場合に返されるメッセージです。
.TP
\fBERROR: RemoveAggregate: aggregate '\fIname\fB' for type \fItype\fB does not exist\fR
指定した集約関数がデータベースに存在しない場合に表示されるメッセージです。
.PP
.SH "説明"
.PP
\fBDROP AGGREGATE\fR を実行すると、既存の集約関数定義を削除することができます。 このコマンドを実行するには、現在のユーザがその集約関数を所有している必要があります。
.SS "注釈"
.PP
集約関数を作成するには、CREATE AGGREGATE [\fBcreate_aggregate\fR(l)] を使用して下さい。
.SH "使用方法"
.PP
int4 型の myavg 集約関数を削除するには、以下のようにします。
.sp
.nf
DROP AGGREGATE myavg(int4);
  
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には、\fBDROP AGGREGATE\fR 文はありません。 この文は、PostgreSQL の言語拡張です。
