.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP FUNCTION" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP FUNCTION \- ユーザ定義の関数の削除
.SH SYNOPSIS
.sp
.nf
DROP FUNCTION \fIname\fR ( [ \fItype\fR [, ...] ] ) [ CASCADE | RESTRICT ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
既存の関数の名前です (スキーマ修飾名でも可)。
.TP
\fB\fItype\fB\fR
その関数のパラメータのデータ型です。
.TP
\fBCASCADE\fR
関数に依存するオブジェクト (演算子またはトリガなど) を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、その関数の削除要求を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP FUNCTION\fR
コマンドが問題なく処理された場合に返されるメッセージです。
.TP
\fBWARNING: RemoveFunction: Function "\fIname\fB" ("\fItypes\fB") does not exist\fR
このメッセージは、指定した関数が現在のデータベースに存在しない場合に表示されます。
.PP
.SH "説明"
.PP
DROP FUNCTION を実行すると、既存の関数の定義を削除することができます。このコマンドを実行するユーザは、その関数の所有者でなければなりません。 異なる引数リストをもった、同じ名前の複数の異なる関数が存在する可能性があるため、関数の入力引数のデータ型を必ず指定しておく必要があります。
.SH "注釈"
.PP
関数の作成についての情報は、CREATE FUNCTION [\fBcreate_function\fR(l)] を参照して下さい。
.SH "例"
.PP
下記のコマンドを実行すると、平方根関数を削除できます。
.sp
.nf
DROP FUNCTION sqrt(integer);
.sp
.fi
.SH "互換性"
.PP
\fBDROP FUNCTION\fR 文は SQL99 で定義されています。 その構文形式の 1 つは、PostgreSQL での構文形式によく似ています。
.SH "関連項目"
CREATE FUNCTION [\fBcreate_function\fR(l)]
