.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SHOW" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
SHOW \- 実行時パラメータの値の表示
.SH SYNOPSIS
.sp
.nf
SHOW \fIname\fR
  
.sp
.fi
.sp
.nf
SHOW ALL
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
実行時パラメータ名。そのリストは SET [\fBset\fR(l)] を参照して下さい。
.TP
\fBALL\fR
現在のセッションパラメータのすべてを表示します。
.PP
.SH "説明"
.PP
\fBSHOW\fR は、実行時パラメータの現在の設定を表示します。 これらの変数は、\fBSET\fR 文で \fIpostgresql.conf\fR を編集することで設定します。\fIpostgresql.conf\fR の編集は、\fBPGOPTIONS\fR 環境変数、または \fBpostmaster\fR の始動時のコマンドラインフラグを使用して行います。
.PP
autocommit が off に設定されている場合でも、\fBSHOW\fR コマンドは新しいトランザクションブロックを開始しません。 詳細については、\fI管理者用ガイド\fRの autocommit の節を参照してください。
.SH "診断"
.PP
.TP
\fBERROR: Option '\fIname\fB' is not recognized\fR
\fIname\fR が存在するパラメータを表していない場合にこのメッセージが返されます。
.PP
.SH "例"
.PP
現在の DateStyle の設定を表示します。
.sp
.nf
SHOW DateStyle;
               DateStyle
---------------------------------------
 ISO with US (NonEuropean) conventions
(1 row )
.sp
.fi
.PP
現在の遺伝的オプティマイザ (geqo) の設定を表示します。
.sp
.nf
SHOW GEQO;
 geqo
------
 on
(1 row )
.sp
.fi
.PP
すべての設定を表示します。
.sp
.nf
SHOW ALL;
             name              |                setting
-------------------------------+---------------------------------------
 australian_timezones          | off
 authentication_timeout        | 60
 checkpoint_segments           | 3
    .
    .
    .
 wal_debug                     | 0
 wal_sync_method               | fdatasync
(94 rows)
.sp
.fi
.SH "互換性"
.PP
\fBSHOW\fR コマンドは PostgreSQL の拡張です。
.SH "関連項目"
.PP
関数 \fBcurrent_setting\fR も同等の出力を作成します。 \fIPostgreSQL ユーザガイド\fRの\fIその他の関数\fRの節を参照してください。
