.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CLOSE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
CLOSE \- カーソルを閉じる
.SH SYNOPSIS
.sp
.nf
CLOSE \fIcursor\fR
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIcursor\fB\fR
閉じる対象の、現在開いているカーソルの名前
.PP
.SS "出力"
.PP
.TP
\fBCLOSE CURSOR\fR
もしカーソルが問題なく閉じられた場合に返されるメッセージです。
.TP
\fBWARNING: PerformPortalClose:portal "\fIcursor\fB" not found\fR
\fIcursor\fRが宣言されていないか、すでに閉じられている場合に返されます。
.PP
.SH "説明"
.PP
\fBCLOSE\fR は開いたカーソルに関連するリソースを解放します。カーソルが閉じらた後は、そのカーソルに対する操作はできません。カーソルは必要がなくなったときに閉じるべきです。
.PP
トランザクションが \fBCOMMIT\fR もしくは \fBROLLBACK\fR で終了された時点で、開いているカーソルすべてに対して暗黙的な閉鎖が実行されます。
.SS "注釈"
.PP
PostgreSQL は明示的な \fBOPEN\fR カーソル文を持ちません。 カーソルは宣言されたときに開いているとみなれます。カーソルの宣言には \fBDECLARE\fR 文を使用してください。
.SH "使用方法"
.PP
liahona というカーソルを閉じる場合には以下のようにします。
.sp
.nf
CLOSE liahona;
  
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
\fBCLOSE\fR は SQL92 と完全に互換性があります。
