.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP CAST" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP CAST \- ユーザ定義のキャストの削除
.SH SYNOPSIS
.sp
.nf
DROP CAST (\fIsourcetype\fR AS \fItargettype\fR)
    [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP CAST\fR を使用すると、以前に定義したキャストを削除できます。
.PP
キャストを削除可能にするには、変換元または変換先のデータ型を所有している必要があります。 これらは、キャストを作成するのに必要な権限と同じです。
"パラメータ"
.TP
\fB\fIsourcetype\fB\fR
キャストする変換元のデータ型の名前です。
.TP
\fB\fItargettype\fB\fR
キャストする変換先のデータ型の名前です。
.TP
\fBCASCADE\fR
.TP
\fBRESTRICT\fR
これらのキーワードを指定しても、キャストに対する依存関係がないため、効果はありません。
.SH "注釈"
.PP
ユーザ定義のキャストを作成するには、\fBCREATE CAST\fR を使用します。
.SH "例"
.PP
\fBtext\fR 型から \fBint\fR 型へのキャストを削除するには、以下のようにします。
.sp
.nf
DROP CAST (text AS int4);
.sp
.fi
.SH "互換性"
.PP
\fBDROP CAST\fR コマンドは、SQL99 に準拠しています。
.SH "関連項目"
.PP
CREATE CAST [\fBcreate_cast\fR(l)]
