.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP VIEW" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP VIEW \- ビューの削除
.SH SYNOPSIS
.sp
.nf
DROP VIEW \fIname\fR [, ...] [ CASCADE | RESTRICT ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
既存のビューの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
削除するビューに依存しているオブジェクト (他のビューなど) を自動的に削除します。
.TP
\fBRESTRICT\fR
依存オブジェクトがある場合に、そのビューの削除を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP VIEW\fR
コマンドが正常に実行された場合に返されるメッセージです。
.TP
\fBERROR: view \fIname\fB does not exist\fR
指定したビューがデータベースに存在しない場合に表示されるメッセージです。
.PP
.SH "説明"
.PP
\fBDROP VIEW\fRは既存のビューをデータベースから削除します。このコマンドを実行するには、ビューの所有者でなければなりません。
.SS "注釈"
.PP
ビューの作成方法に関する情報については CREATE VIEW [\fBcreate_view\fR(l)] を参照して下さい。
.SH "使用方法"
.PP
下記のコマンドは kinds という名前のビューを削除します。
.sp
.nf
DROP VIEW kinds;
  
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
