.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ROLLBACK" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
ROLLBACK \- 現在のトランザクションのアボート
.SH SYNOPSIS
.sp
.nf
ROLLBACK [ WORK | TRANSACTION ]
  
.sp
.fi
.SS "入力"
.PP
ありません。
.SS "出力"
.PP
.TP
\fBROLLBACK\fR
成功時に返されるメッセージです。
.TP
\fBWARNING: ROLLBACK: no transaction in progress\fR
現在進行中のトランザクションが何もない場合です。 
.PP
.SH "説明"
.PP
\fBROLLBACK\fR は現在のトランザクションをロールバックし、そのトランザクションでおこなわれた全ての更新を廃棄させます。
.SS "注釈"
.PP
トランザクションをきちんと終了させるためには    COMMIT   [\fBcommit\fR(l)]を使います。ABORT [\fBabort\fR(l)] は\fBROLLBACK\fR の同義語です。
.SH "使用方法"
.PP
すべての変更をアボートします。
.sp
.nf
ROLLBACK WORK;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 でROLLBACK と ROLLBACK WORKという2つのみが仕様に記述されています。この点以外は完全に互換性があります。
