.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER DATABASE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER DATABASE \- データベースへの変更
.SH SYNOPSIS
.sp
.nf
ALTER DATABASE \fIname\fR SET \fIvariable\fR { TO | = } { \fIvalue\fR | DEFAULT }
ALTER DATABASE \fIname\fR RESET \fIvariable\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER DATABASE\fR を使用して、PostgreSQL データベースにおける実行時設定変数のセッションのデフォルト値を変更できます。 このコマンドで指定された値が、コマンド実行後にデータベースで開始される新規セッションのデフォルト値になります。 データベースで指定されるデフォルト値により、\fIpostgresql.conf\fR ファイルに記述されている設定や、postmaster から受け取った設定は上書きされます。
.PP
データベースにおけるセッションのデフォルト値を変更できるのは、スーパーユーザ、もしくはデータベースの所有者のみです。
.SS "パラメータ"
.PP
.TP
\fB\fIname\fB\fR
セッションのデフォルト値を変更する対象となるデータベースの名前です。
.TP
\fB\fIvariable\fB\fR
.TP
\fB\fIvalue\fB\fR
設定変数におけるこのデータベースのセッションのデフォルト値を、指定した値に設定します。 \fIvalue\fR が DEFAULT であるか、あるいは RESET が使用されている場合、データベースで指定された変数の設定は無効になり、新しいセッションではシステム全体のデフォルト設定が継承されます。 すべての設定をクリアするには、RESET ALL を使用してください。

使用可能な変数名および値についての詳細は、SET [\fBset\fR(l)] および\fI管理者用ガイド\fRを参照してください。
.PP
.SH "診断"
.PP
.TP
\fBALTER DATABASE\fR
変更に成功した場合に返されるメッセージです。
.TP
\fBERROR: database "dbname" does not exist\fR
指定されたデータベースがシステムに認知されていない場合に返されるエラーメッセージです。
.PP
.SH "注釈"
.PP
ALTER USER [\fBalter_user\fR(l)] を使用すると、データベースではなく特定のユーザにセッションのデフォルト値を関連付けることもできます。 競合する場合には、ユーザ固有の設定により、データベース固有の設定が上書きされます。
.SH "例"
.PP
データベース test において、デフォルトでインデックススキャンを無効にするには、次のようにします。
.sp
.nf
ALTER DATABASE test SET enable_indexscan TO off;
.sp
.fi
.SH "互換性"
.PP
\fBALTER DATABASE\fR 文は、PostgreSQL の拡張です。
.SH "関連項目"
ALTER USER [\fBalter_user\fR(l)], CREATE DATABASE [\fBcreate_database\fR(l)],    DROP DATABASE   [\fBdrop_database\fR(l)], SET [\fBset\fR(l)]
