.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE DOMAIN" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE DOMAIN \- 新しいドメインの定義
.SH SYNOPSIS
.sp
.nf
CREATE DOMAIN \fIdomainname\fR [AS] \fIdata_type\fR
    [ DEFAULT \fIdefault_expr\fR ]
    [ \fIconstraint\fR [ ... ] ]

ここでの\fI制約\fRは、以下の通りです。

[ CONSTRAINT \fIconstraint_name\fR ]
{ NOT NULL | NULL }
  
.sp
.fi
.SS "パラメータ"
.PP
.TP
\fB\fIdomainname\fB\fR
作成するドメインの名前です (スキーマ修飾名でも可)。
.TP
\fB\fIdata_type\fB\fR
ドメインの基礎をなすデータ型です。これには、配列指定子が含まれる場合があります。データ型と配列のより詳細については \fIユーザガイド\fR を参照して下さい。
.TP
\fBDEFAULT\fR
DEFAULT 句を使用すると、ドメインデータ型の列にデフォルト値を指定できます。 その値は、任意の無変数式です (ただし、副 select は許可されません)。 デフォルト式のデータ型は、そのドメインのデータ型と一致する必要があります。

デフォルト式は、その列に値が指定されない、全ての挿入操作において使用されます。 ドメインにデフォルトがない場合、デフォルト値は NULL になります。
.sp
.RS
.B "Note:"
デフォルト値が特定の列に指定された場合、ドメインに関連付けられている任意のデフォルト値はすべて上書きされます。 同様に、ドメインのデフォルト値は、基礎をなすデータ型に関連付けられた任意のデフォルト値も上書きします。
.RE
.sp
.TP
\fBCONSTRAINT \fIconstraint_name\fB\fR
この制約には、オプションで名前を指定できます。指定されなければ、システムが名前を生成します。
.TP
\fBNOT NULL\fR
このドメインの値として NULL を使用できません。 
.TP
\fBNULL\fR
このドメインの値として NULL を使用できます。これがデフォルトです。

この句は非標準的な SQL データベースとの互換性のためだけに使用可能です。新しいアプリケーションでこれを使用しないで下さい。
.PP
.SS "出力"
.PP
.TP
\fBCREATE DOMAIN\fR
ドメインの作成に成功した場合に返されるメッセージです。
.PP
.SH "説明"
.PP
\fBCREATE DOMAIN\fR を実行すると、ユーザは、現在のデータベースで使用する新しいデータドメインを PostgreSQL に登録することができます。 ドメインを定義したユーザが、その所有者となります。
.PP
スキーマ名が付けられている場合 (たとえば、CREATE DOMAIN myschema.mydomain ...)、ドメインは指定されたスキーマで作成されます。 付けられていなければ、そのドメインは現在のスキーマ (検索パスの前にあるスキーマ。CURRENT_SCHEMA() 参照) で作成されます。 ドメイン名は、そのスキーマ内に存在するデータ型およびドメインの間で、一意である必要があります。
.PP
ドメインを使用すると、テーブル間で共通なフィールドをメンテナンスのために 1 箇所にまとめることができ、便利です。 たとえば、E-mail アドレスの列が複数のテーブルで使用されていて、すべて同じプロパティを持っている場合があります。 各テーブルに個別に制約を設定するよりも、ドメインを定義し、この機能を使用してください。
.SH "例"
.PP
以下の例では、\fBcountry_code\fR データ型を作成し、その型をテーブル定義の中で使用しています。
.sp
.nf
CREATE DOMAIN country_code char(2) NOT NULL;
CREATE TABLE countrylist (id INT4, country country_code);
.sp
.fi
.SH "互換性"
.PP
SQL99 でも CREATE DOMAIN は定義されていますが、設定できる制約は CHECK 制約のみです。 ドメインの CHECK 制約は、PostgreSQL ではまだサポートされていません。
.SH "関連項目"
   DROP DOMAIN   [\fBdrop_domain\fR(l)], \fIPostgreSQL プログラマガイド\fR
