.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DEALLOCATE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DEALLOCATE \- プリペアードクエリの削除
.SH SYNOPSIS
.sp
.nf
   DEALLOCATE [ PREPARE ] \fIplan_name\fR
  
.sp
.fi
.SS "入力"
.PP
.TP
\fBPREPARE\fR
このキーワードは無視されます。
.TP
\fB\fIplan_name\fB\fR
削除するプリペアードクエリの名前です。
.PP
.SS "出力"
.PP
.TP
\fBDEALLOCATE\fR
プリペアードクエリは正常に削除されました。
.PP
.SH "説明"
.PP
\fBDEALLOCATE\fR を使用すると、以前に準備された問い合わせを削除できます。 プリペアードクエリに明示的に \fBDEALLOCATE\fR を指定しなければ、その問い合わせはセッションの終了時に削除されます。
.PP
プリペアードクエリについての詳細は、PREPARE [\fBprepare\fR(l)] を参照してください。
.SH "互換性"
.SS "SQL92"
.PP
SQL92 にも \fBDEALLOCATE\fR 文はありますが、これは埋め込み SQL クライアントで使用するためだけのものです。
