.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "START TRANSACTION" "" "2002-07-26" "SQL - 言語" "SQL コマンド"
.SH NAME
START TRANSACTION \- トランザクションブロックの開始
.SH SYNOPSIS
.sp
.nf
START TRANSACTION [ ISOLATION LEVEL { READ COMMITTED | SERIALIZABLE } ]
  
.sp
.fi
.SS "入力"
.PP
ありません。
.SS "出力"
.PP
.TP
\fBSTART TRANSACTION\fR
成功した時に返されるメッセージです。
.TP
\fBWARNING: BEGIN:already a transaction in progress\fR
コマンドが発行された時に、既に実行中のトランザクションがある場合に返されるメッセージです。
.PP
.SH "説明"
.PP
このコマンドは新しいトランザクションを開始します。 隔離レベルが指定されていれば、新しいトランザクションはその隔離レベルに設定されます。 他のすべての点において、このコマンドの振る舞いは BEGIN [\fBbegin\fR(l)] コマンドと同じです。
.SH "注釈"
.PP
トランザクションの隔離レベルは、SET TRANSACTION [\fBset_transaction\fR(l)] コマンドを使用して設定することもできます。 隔離レベルが指定されていない場合は、デフォルトの隔離レベルが使用されます。
.SH "互換性"
.SS "SQL99"
.PP
\fBSERIALIZABLE\fR は SQL99 ではデフォルトの隔離レベルですが、PostgreSQL の通常のデフォルトではありません。製品出荷時の設定は READ COMMITTED です。PostgreSQL は \fBREAD UNCOMMITTED\fR と \fBREPEATABLE READ\fR という隔離レベルを提供していません。 述部ロックを行えないので、\fBSERIALIZABLE\fR レベルは厳密にはシリアライザブルではありません。詳細は\fIユーザガイド\fRを参照してください。
.PP
SQL99 ではこの文で、新しいトランザクションについて次の 2 つのプロパティを指定できます。トランザクションが読み取り専用であるかどうかということと診断領域のサイズです 。 これらの概念は現在 PostgreSQL ではサポートされていません。
