.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "UNLISTEN" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
UNLISTEN \- 通知の監視の停止
.SH SYNOPSIS
.sp
.nf
UNLISTEN { \fInotifyname\fR | * }
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fInotifyname\fB\fR
事前に登録された通知条件名を指定します。
.TP
\fB*\fR
現在このコマンドの処理を行なうバックエンドにある、全ての監視登録をクリアします。
.PP
.SS "出力"
.PP
.TP
\fBUNLISTEN\fR
命令文が実行された証明です。
.PP
.SH "説明"
.PP
\fBUNLISTEN\fRは、既存の \fBNOTIFY\fR による登録を削除することに使用します。 \fBUNLISTEN\fR は現在の PostgreSQL セッションにある、通知条件 \fInotifyname\fR 用のリスナ登録を全て取り消します。ワイルドカード*は特別な条件を示すもので、現在のセッションにある全てのリスナ登録を取り消します。
.PP
NOTIFY [\fBnotify\fR(l)]には、\fBLISTEN\fR と \fBNOTIFY\fR についての、より広範な説明があります。
.SS "注釈"
.PP
\fInotifyname\fR は有効なクラス名である必要はありませんが、その文字列長には 64 文字までという制限があります。
.PP
監視をしていないものに対して UNLISTEN を行なったとしても、バックエンドは警告を行ないません。各バックエンドはその終了時に自動的に \fBUNLISTEN *\fR を実行します。
.SH "使用方法"
.PP
次の既存の登録に対して実行してみます。
.sp
.nf
LISTEN virtual;
LISTEN
NOTIFY virtual;
NOTIFY
Asynchronous NOTIFY 'virtual' from backend with pid '8448' received
.sp
.fi
.PP
一度 \fBUNLISTEN\fR コマンドが実行されると、下記の例のように、それ以降の \fBNOTIFY\fR コマンドは無視されます。
.sp
.nf
UNLISTEN virtual;
UNLISTEN
NOTIFY virtual;
NOTIFY
-- NOTIFYイベントを受けとっていないことに注目して下さい。
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には \fBUNLISTEN\fR 文はありません。
