.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP GROUP" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP GROUP \- ユーザグループの削除
.SH SYNOPSIS
.sp
.nf
DROP GROUP \fIname\fR
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
既存のグループの名前です。
.PP
.SS "出力"
.PP
.TP
\fBDROP GROUP\fR
グループの削除に成功した場合に返されるメッセージです。
.PP
.SH "説明"
.PP
\fBDROP GROUP\fR はデータベースから指定されたグループを削除します。グループの中のユーザは削除されません。
.PP
新規のグループを追加するには   CREATE GROUP   [\fBcreate_group\fR(l)]を使用し、グループのメンバを変更するには、ALTER GROUP [\fBalter_group\fR(l)]を使用して下さい。
.SH "使用方法"
.PP
グループを削除します。
.sp
.nf
DROP GROUP staff;
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には \fBDROP GROUP\fR はありません。
