.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP RULE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP RULE \- 書き換えルールの削除
.SH SYNOPSIS
.sp
.nf
DROP RULE \fIname\fR ON \fIrelation\fR [ CASCADE | RESTRICT ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
削除する既存ルールの名前です。
.TP
\fB\fIrelation\fB\fR
このルールが適用されるリレーションの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
このルールに依存しているオブジェクトを自動的にドロップします。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、このルールの削除を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP RULE\fR
成功した時に返されるメッセージです。
.TP
\fBERROR: Rule "\fIname\fB" not found\fR
このメッセージは、指定したルールが存在しない場合に返されます。
.PP
.SH "説明"
.PP
\fBDROP RULE\fR は指定された PostgreSQL のルールシステムからルールを削除します。 PostgreSQL はすぐにそのルールの適用をやめ、システムカタログからその定義を取り除きます。
.SS "注釈"
.PP
\fBDROP RULE\fR 文は PostgreSQL の言語拡張です。
.PP
ルールの作成方法に関する情報については \fBCREATE RULE\fR を参照して下さい。
.SH "使用方法"
.PP
書き換えルール newrule を削除するには以下のようにします。
.sp
.nf
DROP RULE newrule ON mytable;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には \fBDROP RULE\fR はありません。
