.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP INDEX" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP INDEX \- インデックスの削除
.SH SYNOPSIS
.sp
.nf
DROP INDEX \fIindex_name\fR [, ...] [ CASCADE | RESTRICT ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIindex_name\fB\fR
削除するインデックスの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
そのインデックスに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、そのインデックスの削除要求を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP INDEX\fR
コマンドが問題なく処理された場合に返されるメッセージです。
.TP
\fBERROR: index "\fIindex_name\fB" does not exist\fR
このメッセージは、\fIindex_name\fR がそのデータベースのインデックスではない場合に表示されます。
.PP
.SH "説明"
.PP
\fBDROP INDEX\fR を実行すると、データベースシステムから既存のインデックスを削除できます。 このコマンドを実行するには、そのインデックスを所有している必要があります。
.SS "注釈"
.PP
\fBDROP INDEX\fR は PostgreSQL 言語拡張です。
.PP
インデックスの作成方法に関する情報については CREATE INDEX [\fBcreate_index\fR(l)] を参照して下さい。
.SH "使用方法"
.PP
下記のコマンドを実行すると、title_idx インデックスを削除できます。
.sp
.nf
DROP INDEX title_idx;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 では、一般的なリレーショナルデータベースにアクセスするコマンド群を定義しています。 インデックスは実装依存の機能ですので、インデックスに特有なコマンドまたは定義は SQL92 言語にはありません。
