.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "EXECUTE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
EXECUTE \- プリペアードクエリの実行
.SH SYNOPSIS
.sp
.nf
   EXECUTE \fIplan_name\fR [ (\fIparameter\fR [, ...] ) ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIplan_name\fB\fR
実行するプリペアードクエリの名前です。
.TP
\fB\fIparameter\fB\fR
プリペアードクエリに対するパラメータの実際の値です。 この値は、このプリペアードクエリを作成した \fBPREPARE\fR 文内でこのパラメータ位置に指定したデータ型と互換性のあるデータ型の値を生み出す式である必要があります。
.PP
.SH "説明"
.PP
\fBEXECUTE\fR は、既に準備済みである問い合わせを実行する際に使用します。 プリペアードクエリは 1 セッション中にしか存在できないため、プリペアードクエリとは、同じセッション中の前の段階で \fBPREPARE\fR 文によって作成されたものでなければなりません。
.PP
問い合わせを作成した \fBPREPARE\fR 文にパラメータが指定されている場合には、これに適合するパラメータのセットが \fBEXECUTE\fR に渡される必要があります。渡されないと、エラーになります。 (関数とは異なり) プリペアードクエリは、パラメータのデータ型や数によってオーバーロードすることはありません。 プリペアードクエリの名前は、1 つのデータベースセッション内で一意であることが必要です。
.PP
プリペアードクエリの作成と使用方法についての詳細は PREPARE [\fBprepare\fR(l)] を参照してください。
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には \fBEXECUTE\fR 文が含まれていますが、これは埋め込み SQL クライアントでのみ使用できます。 また、PostgreSQL に実装されている \fBEXECUTE\fR 文では多少異なる構文が使用されます。
