.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP TABLE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP TABLE \- テーブルの削除
.SH SYNOPSIS
.sp
.nf
DROP TABLE \fIname\fR [, ...] [ CASCADE | RESTRICT ]

  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
削除する既存のテーブルの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
削除するテーブルに依存しているオブジェクト (ビューなど) を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、このテーブルの削除を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP TABLE\fR
コマンドが問題なく処理された場合に返されるメッセージです。
.TP
\fBERROR: table "\fIname\fB" does not exist\fR
指定したテーブルがデータベースに存在しない場合に返されるメッセージです。
.PP
.SH "説明"
.PP
\fBDROP TABLE\fR はデータベースからテーブルを削除します。テーブルを削除できるのは、その所有者のみです。 \fBDELETE\fR コマンドではテーブルから行を削除することはできますが、テーブルそのものを削除することはできません。
.PP
\fBDROP TABLE\fR は削除対象のテーブル内に存在するインデックス、ルール、トリガおよび制約もすべて削除します。 しかし、他のテーブルの外部キー制約によって参照されているテーブルを削除するには CASCADE を指定する必要があります。 (CASCADE は外部キー制約を削除するものであって、その外部キーを持つテーブルそのものを削除するのではありません。）
.SS "注釈"
.PP
テーブルの作成方法および変更方法に関する情報については、それぞれ \fBCREATE TABLE\fR と \fBALTER TABLE\fR を参照して下さい。
.SH "使用方法"
.PP
2 つのテーブル、films と distributors を削除するには以下のようにします。
.sp
.nf
DROP TABLE films, distributors;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
