.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER TRIGGER" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER TRIGGER \- トリガ定義の変更
.SH SYNOPSIS
.sp
.nf
ALTER TRIGGER \fItrigger\fR ON \fItable\fR
    RENAME TO \fInewname\fR
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fItrigger \fB\fR
変更の対象となる既存のトリガの名前です。
.TP
\fB\fItable \fB\fR
このトリガで処理されるテーブルの名前です。
.TP
\fB\fInewname \fB\fR
既存のトリガの新しい名前です。
.PP
.SS "出力"
.PP
.TP
\fBALTER TRIGGER\fR
トリガの名前が変更された場合に返されるメッセージです。
.TP
\fBERROR\fR
トリガが使用不可能であるか、または新しいトリガ名がテーブルの既存のトリガ名と重複する場合に返されるメッセージです。
.PP
.SH "説明"
.PP
\fBALTER TRIGGER\fR を使用すると、既存のトリガ定義を変更できます。 また、RENAME 句を使用すると、トリガ定義は変更せずに、指定されたテーブルのトリガ名を変更することができます。
.PP
トリガのプロパティを変更するには、トリガで処理されるテーブルを所有している必要があります。
.SS "注釈"
.PP
有効な引数の詳細については、\fBCREATE TRIGGER\fR を参照してください。
.SH "使用方法"
.PP
既存のトリガの名前を変更するには、以下のようにします。
.sp
.nf
ALTER TRIGGER emp_stamp ON emp RENAME TO emp_track_chgs;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
トリガの名前を変更する句は、SQL92 からの PostgreSQL の拡張です。
