.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP SEQUENCE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP SEQUENCE \- シーケンスの削除
.SH SYNOPSIS
.sp
.nf
DROP SEQUENCE \fIname\fR [, ...] [ CASCADE | RESTRICT ]

  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
シーケンスの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
このシーケンスに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存オブジェクトがある場合に、このシーケンスの削除を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP SEQUENCE\fR
シーケンスの削除に成功すると返されるメッセージです。
.TP
\fBERROR: sequence "\fIname\fB" does not exist\fR
このメッセージは、指定したシーケンスが存在しない場合に出されます。
.PP
.SH "説明"
.PP
\fBDROP SEQUENCE\fR はシーケンス番号生成機構をデータベースから削除します。 現在のシーケンスは特別なテーブルとして実装されていますので、このコマンドは \fBDROP TABLE\fR 文と同じように動作します。
.SS "注釈"
.PP
\fBDROP SEQUENCE\fR 文は PostgreSQL の言語拡張です。
.PP
シーケンスの作成方法に関する情報については \fBCREATE SEQUENCE\fR を参照して下さい。
.SH "使用方法"
.PP
シーケンス serial をデータベースから削除するには以下のようにします。
.sp
.nf
DROP SEQUENCE serial;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には \fBDROP SEQUENCE\fR はありません。
