.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CHECKPOINT" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
CHECKPOINT \- 強制的にトランザクションログのチェックポイントを実行
.SH SYNOPSIS
.sp
.nf
CHECKPOINT
.sp
.fi
.SH "説明"
.PP
WAL（Write-Ahead Logging）は、頻繁にチェックポイントをトランザクションログに設定します（自動的なチェックポイントの間隔の調整については、実行時の構成オプションの \fICHECKPOINT_SEGMENTS\fR と \fICHECKPOINT_TIMEOUT\fR を参照してください）。\fBCHECKPOINT\fR コマンドは、コマンドが発行されると、予定されているチェックポイントを待つことなく、即座にチェックポイントを設定します。
.PP
チェックポイントは、ログに情報を反映するためすべてのデータファイルが更新された時点での、連続したトランザクションログにおけるポイントです。すべてのデータファイルはディスクに書き出されます。WAL システムの詳細については、\fIPostgreSQL 管理者用ガイド\fRを参照してください。
.PP
スーパーユーザだけが \fBCHECKPOINT\fR を実行できます。このコマンドは、通常動作での使用は目的としていません。
.SH "関連項目"
.PP
\fIPostgreSQL 管理者用ガイド\fR
.SH "互換性"
.PP
\fBCHECKPOINT\fR コマンドは、PostgreSQL の言語拡張です。
