.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER GROUP" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER GROUP \- グループへのユーザを追加、またはグループからのユーザの削除
.SH SYNOPSIS
.sp
.nf
ALTER GROUP \fIname\fR ADD USER \fIusername\fR [, ... ] ]
ALTER GROUP \fIname\fR DROP USER \fIusername\fR [, ... ] ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
変更するグループの名前です。
.TP
\fB\fIusername\fB\fR
グループに追加もしくは削除されるユーザです。ユーザ名は存在するものでなければいけません。
.PP
.SS "出力"
.PP
.TP
\fBALTER GROUP\fR
変更に成功した場合に返されるメッセージです。
.PP
.SH "説明"
.PP
\fBALTER GROUP\fR は、ユーザをグループに追加もしくはグループから削除するために使われます。データベーススーパーユーザのみがこのコマンドを使うことができます。グループにユーザを追加するだけでは新しいユーザを作成しません。同様に、グループからユーザを削除してもユーザ自体を削除することにはなりません。
.PP
新しいグループを作成するには    CREATE GROUP   [\fBcreate_group\fR(l)] を、グループを削除するには    DROP GROUP   [\fBdrop_group\fR(l)] を使用して下さい。
.SH "使用方法"
.PP
ユーザをグループに追加するには、以下のようにします。
.sp
.nf
ALTER GROUP staff ADD USER karl, john;
.sp
.fi
ユーザをグループから削除するには、以下のようにします。
.sp
.nf
ALTER GROUP workers DROP USER beth;
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には \fBALTER GROUP\fR 文はありません。role が概念的にはグループに似ています。
