.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SELECT" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
SELECT \- テーブルもしくはビューからの行の検索
.SH SYNOPSIS
.sp
.nf
SELECT [ ALL | DISTINCT [ ON ( \fIexpression\fR [, ...] ) ] ]
    * | \fIexpression\fR [ AS \fIoutput_name\fR ] [, ...]
    [ FROM \fIfrom_item\fR [, ...] ]
    [ WHERE \fIcondition\fR ]
    [ GROUP BY \fIexpression\fR [, ...] ]
    [ HAVING \fIcondition\fR [, ...] ]
    [ { UNION | INTERSECT | EXCEPT } [ ALL ] \fIselect\fR ]
    [ ORDER BY \fIexpression\fR [ ASC | DESC | USING \fIoperator\fR ] [, ...] ]
    [ LIMIT { \fIcount\fR | ALL } ]
    [ OFFSET \fIstart\fR ]
    [ FOR UPDATE [ OF \fItablename\fR [, ...] ] ]

ここで、\fIfrom_item\fR は以下のとおりです。

[ ONLY ] \fItable_name\fR [ * ]
    [ [ AS ] \fIalias\fR [ ( \fIcolumn_alias_list\fR ) ] ]
|
( \fIselect\fR )
    [ AS ] \fIalias\fR [ ( \fIcolumn_alias_list\fR ) ]
|
\fItable_function_name\fR ( [ \fIargument\fR [, ...] ] )
    [ AS ] \fIalias\fR [ ( \fIcolumn_alias_list\fR | \fIcolumn_definition_list\fR ) ]
|
\fItable_function_name\fR ( [ \fIargument\fR [, ...] ] )
    AS ( \fIcolumn_definition_list\fR )
|
\fIfrom_item\fR [ NATURAL ] \fIjoin_type\fR \fIfrom_item\fR
    [ ON \fIjoin_condition\fR | USING ( \fIjoin_column_list\fR ) ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIexpression\fB\fR
テーブルの列名もしくは式です。
.TP
\fB\fIoutput_name\fB\fR
AS 句を使い、出力列の別の名前を指定します。この名前は主に表示する列を名づけるために使われます。他には ORDER BY と GROUP BY 句の中の列の値を参照するのに使われることもあります。しかし \fIoutput_name\fRは WHERE もしくは HAVING 句で使うことはできません。 代わりに式を書いて下さい。
.TP
\fB\fIfrom_item\fB\fR
テーブル参照、副 SELECT、テーブル関数、もしくは JOIN 句です。詳細は下記を参照して下さい。
.TP
\fB\fIcondition\fB\fR
真か偽の結果を返すブーリアン式です。WHERE と HAVING 句の説明は下記を参照して下さい。
.TP
\fB\fIselect\fB\fR
ORDER BY、LIMIT/OFFSET、そして FOR UPDATE 句を除く全ての機能を備えた select 文です (select 式をカッコでくくれば、ORDER BY、LIMIT/OFFSET、FOR UPDATE も使用できます)。
.PP
.PP
FROM アイテムは下記を含むことができます。
.TP
\fB\fItable_name\fB\fR
既存のテーブルまたはビューの名前です (スキーマ修飾名でも可)。 ONLY が指定された場合、そのテーブルのみがスキャンされます。 もし ONLY が指定されない場合、テーブルとそれを継承するすべてのテーブルがスキャンされます。 継承テーブルがスキャンされることを表すために、テーブル名に * を付けることができますが、現在のバージョンでは、継承テーブルのスキャンはデフォルトで行われます。 (7.1 より前のリリースでは、ONLY がデフォルトでした。) デフォルトの振る舞いを変更するには、\fBSQL_INHERITANCE\fR 構成オプションを変更します。
.TP
\fB\fIalias\fB\fR
別名を含む FROM アイテムの代替名です。別名は簡潔さのため、もしくは自己結合 (同じテーブルが複数回スキャンされる場合です) の曖昧さをなくすために使われます。 別名が指定されている場合は、その別名によって実際のテーブル名またはテーブル関数名が完全に隠されます。例えば、FROM foo AS f と指定されている場合、以降の SELECT 文ではこの FROM アイテムを foo ではなく f として参照する必要があります。テーブルの別名と一緒に、そのテーブルの複数の列の別名リストを付け加えることもできます。
.TP
\fB\fIselect\fB\fR
副 SELECT は FROM 句で使うことができます。これはその出力がこの SELECT コマンド実行時に一時テーブルとして作成されたかのように動作します。副 SELECT はカッコで囲まれなければならず、\fB必ず\fR別名が提供されなければなりません。
.TP
\fB\fItable function\fB\fR
FROM 句にテーブル関数を使用することができます。これはその出力がこの SELECT コマンド実行時に一時テーブルとして作成されたかのように動作します。 また、別名を使用することもできます。 別名があれば、テーブルの別名と一緒にそのテーブル関数の複数の列の別名リストを付け加えることもできます。 テーブル関数が \fBrecord\fR データ型を返すと定義されている場合は、別名すなわちキーワード AS とそれに続く ( \fIcolumn_name\fR \fIdata_type\fR [, ... ] ) という形式の列定義リストが必要です。. 列定義リストは、関数によって返される実際の列の数およびデータ型にマッチしていなければなりません。
.TP
\fB\fIjoin_type\fB\fR
\fB[ INNER ] JOIN\fR,\fBLEFT [ OUTER ] JOIN\fR,\fBRIGHT [ OUTER ] JOIN\fR,\fBFULL [ OUTER ] JOIN\fR, もしくは \fBCROSS JOIN\fR のどれかです。INNER と OUTER 結合型では、正確に一つの NATURAL, ON\fIjoin_condition\fR,もしくは USING ( \fIjoin_column_list\fR ) のいずれかがなくてはいけません。CROSS JOINでは、一切なくてもかまいません。
.TP
\fB\fIjoin_condition\fB\fR
制約条件です。これは WHERE 条件と似ていますが、この JOIN 句で結合される二つの from_item にのみあてはまるという点が違います。
.TP
\fB\fIjoin_column_list\fB\fR
USING 列リスト( a, b, ... ) は ON 条件left_table.a = right_table.a AND left_table.b = right_table.b ...の簡略バージョンです。
.PP
.SS "出力"
.PP
.TP
\fBRows\fR
問い合わせ指定の結果の行の完全な集合です。
.TP
\fB\fIcount\fB\fR
問い合わせが返す行の数です。
.PP
.SH "説明"
.PP
\fBSELECT\fR は一つ以上のテーブルから行を返します。選択される侯補は WHERE 条件を満たす行です。 もし WHERE が省略されると、全ての行が侯補になります。(WHERE 句 [\fBselect\fR(l)]を見て下さい。)
.PP
実際のところ、返される行は FROM/WHERE/GROUP BY/HAVING 句から直接作られる行ではありません。 出力される行はそれぞれの選択された行の SELECT 出力式を計算することで形成されます。\fB*\fR は選択された行の全ての列の省略形としての出力リストに書くことができます。更に、\fItable_name\fR \fB.*\fR はそのテーブルのみからくる列の省略形として書くことができます。
.PP
\fBDISTINCT\fR は結果から重複行を削除します。\fBALL\fR （デフォルトです) は重複行を含む全ての侯補の行を返します。
.PP
\fBDISTINCT ON\fR はそれぞれの重複行の集合の最初の行のみを残し、指定された式に当てはまる行を消します。DISTINCT ON式は ORDER BY アイテムと同じルールを使って解釈されます。 下記を見て下さい。それぞれの集合の ``最初の行'' は\fBORDER BY\fR が望まれる行が最初に出ることを確実にしないかぎりは予測できないことに注意して下さい。以下に例を示します。
.sp
.nf
        SELECT DISTINCT ON (location) location, time, report
        FROM weatherReports
        ORDER BY location, time DESC;
   
.sp
.fi
はそれぞれの場所の最新の気象情報を取りだします。しかしもしそれぞれの場所の時間値を降順に強制するために ORDER BY を使わなかったとしたら、それぞれの場所の予測できない時代の予報を得ることになってしまいます。
.PP
GROUP BY 句によってユーザがテーブルを、一つ以上の値に当てはまる行のグループにわけることができます。(GROUP BY句 [\fBselect\fR(l)]を見て下さい。)
.PP
HAVING 句によって、指定された条件にあう行のグループのみを選択することができます。(HAVING 句 [\fBselect\fR(l)]を見て下さい。)
.PP
ORDER BY 句は、返された行が指定された順にソートされるようにします。もし ORDER BY が与えられないと、行はシステムにとって一番作りやすい順番で返されます。(ORDER BY 句 [\fBselect\fR(l)]を見て下さい。)
.PP
SELECT 問い合わせは UNION, INTERSECT, そして EXCEPT 演算子を使って組み合わせることができます。もしこれらの演算子の順番を決める必要があるときはカッコを使います。
.PP
UNION 演算子は、関連する問い合わせが返す行の集まりを計算します。重複行は ALL が指定されない限り削除されます。(UNION 句 [\fBselect\fR(l)]を見て下さい。)
.PP
INTERSECT 演算子は両方の問い合わせに共通する行を計算します。重複行は ALL が指定されない限り削除されます。(INTERSECT 句 [\fBselect\fR(l)]を見て下さい。)
.PP
EXCEPT 演算子は最初の問い合わせからは返され二番目の問い合わせからは返されない行を計算します。重複行は ALL が指定されない限り削除されます。(EXCEPT 句 [\fBselect\fR(l)]を見て下さい。)
.PP
LIMIT 句はユーザが返すべき問い合わせによって作られる行のサブセットを可能にします。(LIMIT 句 [\fBselect\fR(l)]を見て下さい。)
.PP
FOR UPDATE 句によって SELECT 文は、選択された行が同時更新されないようロックします。
.PP
この値を読み込むにはテーブルに対する SELECT 権限が必要です (\fBGRANT\fR/\fBREVOKE\fR 文に関する説明を参照)。 また FOR UPDATE を使用するには UPDATE 権限も必要です。
.SS "FROM 句"
.PP
FROM 句は一つ以上のソーステーブルを SELECT に指定します。もし複数のソースが指定されると、結果は概念的に全てのソースの全ての行の直積になります。 しかし通常は制約条件は直積の小さなサブセットを制限するために追加されます。
.PP
FROM アイテムが単純なテーブル名の場合、それは暗黙的にそのテーブルのサブテーブル(継承する子)からの行も含みます。\fBONLY\fR はそのテーブルのサブテーブルからの行を抑圧します。PostgreSQL 7.1 以前ではこれはデフォルトの結果で、サブテーブルの追加はテーブル名に \fB*\fR を付けて行なわれていました。 この古い方法はコマンド \fBSET SQL_Inheritance TO OFF\fR で使うことができます。
.PP
FROM アイテムはカッコで囲まれたサブセレクト(別名句がサブセレクトには必要なことに注意して下さい。)であってもかまいません。これは単一の問い合わせの複数レベルのグループ分け、集約、若しくはソートをする唯一の方法なので、非常に便利な機能です。
.PP
FROM アイテムはテーブル関数にすることもできます (どのような関数でも使えますが、複数の行および列を返す関数が一般的)。 関数は、特定の引数値によって呼び出され、その出力はテーブルの場合と同じようにスキャンされます。
.PP
場合によっては、呼び出される方法によって異なる列セットを返せるテーブル関数を定義しておくと便利です。 これを行うには、疑似データ型 \fBrecord\fR を返すようテーブル関数を宣言します。 このような関数を FROM アイテムで使用する場合は、この関数の後に別名またはキーワード AS を単独で記述し、さらに、括弧で囲んだ列名とデータ型を記述します。 これにより、問い合わせ時複合データ型定義が可能になります。 この複合データ型定義は、関数から実際に返される複合データ型とマッチしていなければなりません。マッチしていなければ、実行時にエラーが報告されます。
.PP
最後に、FROM アイテムは二つのより単純な FROM アイテムを組み合われるJOIN 句であることもあります。(ネストの順番を決める必要がある場合カッコを使います。)
.PP
CROSS JOIN もしくは INNER JOIN は単純な直積で、FROM の最上レベルにその二つのアイテムをリストするのと同じものです。CROSS JOIN は INNER JOIN ON (TRUE) と等しく、制約ではどの行も削除されません。これらの結合型は記述上の便宜のためだけであり、これらは何もしないので単純な FROM と WHERE は使えません。
.PP
LEFT OUTER JOIN は条件にあう直積の全ての行(つまり、その ON 条件を渡す全ての組み合わされた行)、そして ON 条件を満たす右側の行を持たない左側のテーブルの各々の行のコピーを返します。 この左側の行は右側の行に NULL 値を挿入することで結合されたテーブルの全幅に拡張されます。 どの行がマッチしているかを決める間、JOIN 自身の ON か USING 条件のみが考慮されることに注意してください。他の ON か WHERE 条件は後で適用されます。
.PP
逆に、RIGHT OUTER JOIN は全ての結合された行と、それぞれの当てはまるものがなかった右側の行(左側は null で拡張されています)に一行ずつを返します。左と右の入力を入れ換えることで LEFT OUTER JOIN に変換することもできるため、これはただの記述上の便宜でしかありません。
.PP
FULL OUTER JOIN は全ての結合された行と、当てはまるものがなかった左側の行(右側が null で拡張されている)と、あてはまるものがなかった右側の行(左側が null で拡張されている)を返します。
.PP
CROSS JOIN を除く全ての JOIN 型では、ON \fIjoin_condition\fR,USING ( \fIjoin_column_list\fR ),もしくは NATURAL のどれかを正確に書かなければいけません。ON はもっとも一般的な場合です。結合されるべき二つのテーブルに関連するどのような制約式でも書くことができます。 USING 列リスト( a, b, ... ) は ON 条件left_table.a = right_table.a AND left_table.b = right_table.b ...の簡略バージョンです。更に USING は、JOIN 出力に含まれるそれぞれのペアの同等の列のうちの両方ではなく一つだけが含まれることを意味します。NATURAL はテーブルのなかの似たような名前を持つ全ての列を挙げる USING リストの簡略バージョンです。
.SS "WHERE 句"
.PP
オプションの WHERE 条件の一般形は次のようになります。
.sp
.nf
WHERE \fIboolean_expr\fR
    
.sp
.fi
\fIboolean_expr\fR はブール値として評価できる表現であればどのような組み合わせでも構成することができます。多くの場合、次のようになります。
.sp
.nf
\fIexpr\fR \fIcond_op\fR \fIexpr\fR
    
.sp
.fi
もしくは
.sp
.nf
\fIlog_op\fR \fIexpr\fR
    
.sp
.fi
ここで、\fIcond_op\fR は、 =, <, <=, >, >= or <> のいずれか、ALL,ANY,IN,LIKEのような条件演算子、もしくは、ローカルに定義された演算子をとることができます。 また、\fIlog_op\fR は AND, OR, NOT のいずれかをとることができます。SELECT は WHERE 条件が TRUE を返さないすべての行を無視します。
.SS "GROUP BY句"
.PP
GROUP BY はこの句のアプリケーションから作られるグループ化されたテーブルを指定します。
.sp
.nf
GROUP BY \fIexpression\fR [, ...]
    
.sp
.fi
.PP
GROUP BY は、グループ化された列と同じ値を共有する全ての選択された行を一つの行に凝縮します。もしあれば、集約関数はそれぞれのグループを作る全ての行を渡って計算され、それぞれのグループに個別の値を作ります(GROUP BY なしでは集約は全ての選択された行に渡って計算される単一の値を作ります)。GROUP BY が存在する場合、集約関数内以外では SELECT 出力式がグループ分けされていない列を参照することは妥当ではありません。 なぜならグループ化されていない列には一つ以上の返却可能な値があるからです。
.PP
GROUP BY アイテムは入力列名、もしくは出力列の順序の番号の名前(SELECT 式)、もしくは入力列の値に形成される任意の式が可能です。不明瞭な場合は、GROUP BY 名は出力列名ではなく入力列名として解釈されます。
.SS "HAVING 句"
.PP
オプションである、HAVING 条件は一般的に次の形式です。
.sp
.nf
HAVING \fIboolean_expr\fR
    
.sp
.fi
ここで、\fIboolean_expr\fR は WHERE 句で指定するものと同一です。
.PP
HAVING によって\fIboolean_expr\fRを満たさない行を削除した結果からグループ化されたテーブルを作ることを指示します。HAVING は WHERE とは違います。WHERE は個別の行を GROUP BYのアプリケーションの前に濾過しますが、HAVING は GROUP BYによって作られるグループ行を濾過します。
.PP
\fIboolean_expr\fR で参照される各列は、参照が集約関数内で現れない限り明瞭にグループ化する列を参照します。
.SS "ORDER BY 句"
.PP
.sp
.nf
ORDER BY \fIexpression\fR [ ASC | DESC | USING \fIoperator\fR ] [, ...]
    
.sp
.fi
.PP
ORDER BY アイテムは名前、もしくは出力列(SELECT 式)の順序の番号、もしくは入力列の値から形成される任意の式を指定することができます。あいまいな場合は、ORDER BY の 名前は出力列名として解釈されます。
.PP
順序の番号は、結果の列の(左から右への)順番の位置を参照します。 この機能は固有の名前を持たない列に基づいた順番を定義することを可能にします。これが絶対に必要だという訳ではありません。 なぜなら AS 句を使って結果の列に名前を与えることはいつでも可能だからです。 例えば下記のようになります。
.sp
.nf
SELECT title, date_prod + 1 AS newlen FROM films ORDER BY newlen;
    
.sp
.fi
.PP
SELECT の結果リストに現れないフィールドを含む任意の式(SQL92 の拡張)を ORDER BY することも可能です。したがって下記の文は正当です。
.sp
.nf
SELECT name FROM distributors ORDER BY code;
    
.sp
.fi
UNION、 INTERSECT、 もしくは EXCEPT 問い合わせの結果に適用する ORDER BY 句では、 式ではなく出力列の名前か番号のみを指定できるので、この機能は使えません。
.PP
もし ORDER BY アイテムが結果の列名と入力列名の両方に当てはまる単純な名前だった場合、ORDER BY はそれを結果列名として解釈します。これは GROUP BY が同じ状況で行なう選択とは逆です。この不一致は標準 SQL92 からくるものです。
.PP
オプションとして、ORDER BY 句の各列名の後にキーワード DESC （降順) もしくは ASC （昇順)を付けることができます。 指定がなければ、デフォルトで ASC になります。代わりに特定の順番演算子の名前を指定することもできます。 ASC は USING < と等しく、DESC は USING > と等しいです。
.PP
null 値はその領域内の他のあらゆる値よりも高くソートされます。言い替えると、順方向のソートではnull値は末尾に、逆方向のソートではnull値は先頭に現れます。
.PP
文字データ型のデータは、データベースクラスタの初期化時に設定されたローカル指定の照合順に従ってソートされます。
.SS "UNION 句"
.PP
.sp
.nf
\fItable_query\fR UNION [ ALL ] \fItable_query\fR
    [ ORDER BY \fIexpression\fR [ ASC | DESC | USING \fIoperator\fR ] [, ...] ]
    [ LIMIT { \fIcount\fR | ALL } ]
    [ OFFSET \fIstart\fR ]
    
.sp
.fi
ここで、\fItable_query\fR は、ORDER BY, LIMIT, もしくは FOR UPDATE 句を持たない任意の select 式を指定できます。(ORDER BY と LIMIT は select がカッコで囲まれていると副式に付けることができます。カッコなしでは、これらの句は右側の入力式ではなく UNION の結果に適用するものとして判断されます。)
.PP
UNION 演算子は、関連する問い合わせが返す行の集合(和集合)を計算します。 UNION の直接の演算項目を表す 2 つの SELECT 文は同じ数の列を作らなければならず、対応する列は互換性のあるデータ型でなければなりません。
.PP
UNION の結果は ALL オプションが指定されない限りどのような重複行も含みません。ALL は重複行を削除しません。
.PP
同じ SELECT 文にある複数の UNION 演算子は、カッコで別の順が示されない限り左から右に評価されます。
.PP
今のところ、FOR UPDATE は UNION の結果もしくは UNION の入力値のどちらにも指定することができません。
.SS "INTERSECT 句"
.PP
.sp
.nf
\fItable_query\fR INTERSECT [ ALL ] \fItable_query\fR
    [ ORDER BY \fIexpression\fR [ ASC | DESC | USING \fIoperator\fR ] [, ...] ]
    [ LIMIT { \fIcount\fR | ALL } ]
    [ OFFSET \fIstart\fR ]
    
.sp
.fi
ここで、\fItable_query\fR は、ORDER BY, LIMIT, もしくは FOR UPDATE 句を持たない任意の select 式を指定できます。
.PP
INTERSECT は UNION と似ていますが、どちらかに現れる行ではなく両方の問い合わせ出力に現れる行のみを作るという点が違います。
.PP
INTERSECT の結果は ALL オプションが指定されない限りどのような重複行も含みません。ALL では、 L に m の重複を持ち、R に n の重複を持つ行は min(m,n) 回現れます。
.PP
同じ SELECT 文の中の複数の INTERSECT 演算子は、カッコで別の指定がない限り左から右に評価されます。INTERSECT は UNION より更に固く結びつけます。 つまりA UNION B INTERSECT C はカッコで別の指定がない限り A UNION (B INTERSECT C) として読まれます。
.SS "EXCEPT 句"
.PP
.sp
.nf
\fItable_query\fR EXCEPT [ ALL ] \fItable_query\fR
    [ ORDER BY \fIexpression\fR [ ASC | DESC | USING \fIoperator\fR ] [, ...] ]
    [ LIMIT { \fIcount\fR | ALL } ]
    [ OFFSET \fIstart\fR ]
    
.sp
.fi
ここで、\fItable_query\fR は、ORDER BY, LIMIT, もしくは FOR UPDATE 句を持たない任意の select 式を指定できます。
.PP
EXCEPT は UNION と似ていますが、右問い合わせの出力ではなく左問い合わせの出力に現れる行を作るという点で違います。
.PP
EXCEPT の結果は ALL オプションが指定されない限りどのような重複行も含みません。ALL では、L に m の重複を持ちR に n の重複を持つ行は max(m-n,0) 回現れます。
.PP
同じ SELECT 文の中の複数の EXCEPT 演算項目は、カッコがそれ以外を指定しない限り左から右に評価されます。EXCEPT は UNION と同じレベルで結びつけられます。
.SS "LIMIT 句"
.PP
.sp
.nf
    LIMIT { \fIcount\fR | ALL }
    OFFSET \fIstart\fR
    
.sp
.fi
\fIcount\fR は返される行の最大数を指定し、\fIstart\fR は行を返しはじめる前に飛ばす行の数を指定します。
.PP
LIMIT はこの問い合わせが生成する行の一部のみを取りだすことを可能にします。もし制限数が与えられると、それ以上の行は返されません。もしオフセットが与えられると、返す行が始まる前にそれだけの行がとばされます。
.PP
LIMIT を使う時は、結果の行を一意な順番に強制するORDER BY 句を使うのが良い考えです。そうしないと、問い合わせの行の予測不可能なサブセットを得ることになります。 10 から 20 行目までを出そうとしているかもしれませんが、どの順番の 10 から 20 行目までなのでしょうか?ORDER BYを指定しない限りどの順番だかわからないのです。
.PP
PostgreSQL 7.0 からは、問い合わせオプティマイザは問い合わせプランを作成する時に LIMIT を 考慮しますので、LIMIT と OFFSET に何を使用するかによって(異なる行の順番を生む)異なったプランを得ることになるでしょう。したがって、問い合わせの、異なるサブセットを選択するために異なる LIMIT/OFFSET の値を使うと、ORDER BY で予測可能な結果を強制しない限り、\fB矛盾した結果を返します\fR。これはバグではありません。 これは SQL が ORDER BY で順番を制御しない限り問い合わせの結果を特定の順番で返すことを約束しないという事実の本質的な結果なのです。
.SS "FOR UPDATE 句"
.PP
.sp
.nf
    FOR UPDATE [ OF \fItablename\fR [, ...] ]
    
.sp
.fi
.PP
FOR UPDATE を使用すると問い合わせによって検索された行が更新用にロックされます。 これにより、現行のトランザクションが終了するまではこれらの行が他のトランザクションによって変更されたり削除されたりすることがなくなります。つまり、現行のトランザクションが終了するまでは、他のトランザクションがこれらの行に対して UPDATE、DELETE、または SELECT FOR UPDATE を試行しても拒否されるのです。 また、他のトランザクションからの UPDATE、DELETE、または SELECT FOR UPDATE によって選択されている行がロックされている場合に SELECT FOR UPDATE を実行しようとすると、SELECT FOR UPDATE は前のトランザクションが終了するのを待ち、その後更新された行をロックして返します (行が削除された場合は返しません)。 詳細については、\fIユーザガイド\fRの同時実行に関する章を参照してください。
.PP
FOR UPDATE 内に特定のテーブルが指定されている場合は、そのテーブル (複数の場合もあり) の行のみがロックされ、SELECT 内の他のテーブルは通常どおりに読み込まれるだけです。
.PP
FOR UPDATE は、返される行が含まれている個々のテーブルを明確に指定できない場合には使用することができません。例えば、集約には使用できません。
.PP
FOR UPDATE は、バージョン 7.3 より前のアプリケーションとの互換性のために LIMIT の前に書くことができます。 しかしその場合でも実際には LIMIT の後に実行されるので、LIMIT の後に書くことをお勧めします。
.SH "使用方法"
.PP
テーブル films をテーブル distributors で結合するには下記のようにします。
.sp
.nf
SELECT f.title, f.did, d.name, f.date_prod, f.kind
    FROM distributors d, films f
    WHERE f.did = d.did

           title           | did |   name           | date_prod  | kind
---------------------------+-----+------------------+------------+----------
 The Third Man             | 101 | British Lion     | 1949-12-23 | Drama
 The African Queen         | 101 | British Lion     | 1951-08-11 | Romantic
 Une Femme est une Femme   | 102 | Jean Luc Godard  | 1961-03-12 | Romantic
 Vertigo                   | 103 | Paramount        | 1958-11-14 | Action
 Becket                    | 103 | Paramount        | 1964-02-03 | Drama
 48 Hrs                    | 103 | Paramount        | 1982-10-22 | Action
 War and Peace             | 104 | Mosfilm          | 1967-02-12 | Drama
 West Side Story           | 105 | United Artists   | 1961-01-03 | Musical
 Bananas                   | 105 | United Artists   | 1971-07-13 | Comedy
 Yojimbo                   | 106 | Toho             | 1961-06-16 | Drama
 There's a Girl in my Soup | 107 | Columbia         | 1970-06-11 | Comedy
 Taxi Driver               | 107 | Columbia         | 1975-05-15 | Action
 Absence of Malice         | 107 | Columbia         | 1981-11-15 | Action
 Storia di una donna       | 108 | Westward         | 1970-08-15 | Romantic
 The King and I            | 109 | 20th Century Fox | 1956-08-11 | Musical
 Das Boot                  | 110 | Bavaria Atelier  | 1981-11-11 | Drama
 Bed Knobs and Broomsticks | 111 | Walt Disney      |            | Musical
(17 rows)
.sp
.fi
.PP
全ての映画の列 len を合計し kind 列によって結果をグループ化するには下記のようにします。
.sp
.nf
SELECT kind, SUM(len) AS total FROM films GROUP BY kind;

 kind     | total
----------+-------
 Action   | 07:34
 Comedy   | 02:58
 Drama    | 14:28
 Musical  | 06:42
 Romantic | 04:38
(5 rows)
.sp
.fi
.PP
全ての映画の列 len を合計し kind 列によって結果をグループ化し、合計が 5 時間より少ないグループの合計を表示します。
.sp
.nf
SELECT kind, SUM(len) AS total
    FROM films
    GROUP BY kind
    HAVING SUM(len) < INTERVAL '5 hour';

 kind     | total
----------+-------
 Comedy   | 02:58
 Romantic | 04:38
(2 rows)
.sp
.fi
.PP
以下の二つの例は個別の結果を二番目の列 (name) の内容に基づいてソートする、同じ方法です。
.sp
.nf
SELECT * FROM distributors ORDER BY name;
SELECT * FROM distributors ORDER BY 2;

 did | name
-----+------------------
 109 | 20th Century Fox
 110 | Bavaria Atelier
 101 | British Lion
 107 | Columbia
 102 | Jean Luc Godard
 113 | Luso films
 104 | Mosfilm
 103 | Paramount
 106 | Toho
 105 | United Artists
 111 | Walt Disney
 112 | Warner Bros.
 108 | Westward
(13 rows)
.sp
.fi
.PP
この例は、結果をそれぞれのテーブルで W で始まるものだけに制限して、どのようにテーブル distributors と actors の結合を獲得するかを表しています。特定の行のみが必要なので、ALL キーワードは省略されています。
.sp
.nf
distributors:               actors:
 did |     name              id |     name
-----+--------------        ----+----------------
 108 | Westward               1 | Woody Allen
 111 | Walt Disney            2 | Warren Beatty
 112 | Warner Bros.           3 | Walter Matthau
 ...                         ...

SELECT distributors.name
    FROM   distributors
    WHERE  distributors.name LIKE 'W%'
UNION
SELECT actors.name
    FROM   actors
    WHERE  actors.name LIKE 'W%';

      name
----------------
 Walt Disney
 Walter Matthau
 Warner Bros.
 Warren Beatty
 Westward
 Woody Allen
.sp
.fi
.PP
この例は、テーブル関数の使用方法 (列定義リストがある場合とない場合の両方) を示しています。
.sp
.nf
distributors:
 did | name
-----+--------------
 108 | Westward
 111 | Walt Disney
 112 | Warner Bros.
 ...

CREATE FUNCTION distributors(int)
  RETURNS SETOF distributors AS '
  SELECT * FROM distributors WHERE did = $1;
  ' LANGUAGE SQL;

SELECT * FROM distributors(111);
 did | name
-----+-------------
 111 | Walt Disney
(1 row )

CREATE FUNCTION distributors_2(int)
  RETURNS SETOF RECORD AS '
  SELECT * FROM distributors WHERE did = $1;
  ' LANGUAGE SQL;

SELECT * FROM distributors_2(111) AS (f1 int, f2 text);
 f1  |     f2
-----+-------------
 111 | Walt Disney
(1 row )
.sp
.fi
.SH "互換性"
.SS "拡張"
.PP
PostgreSQL では問い合わせで\fBFROM\fR 句を省略できます。 これはもとの PostQUEL 問い合わせ言語の機能が保存されていることによるものです。 このようにして単純な式の計算を簡単に行うことができます。
.sp
.nf
SELECT 2+2;

 ?column?
----------
        4
  
.sp
.fi
他の SQL データベースは、select from を行なうためのダミーの一行テーブルを使う以外はこれを行なうことができないものがあります。これほど明確ではない使用法としては一つ以上のテーブルからselect することを次のように省略して書くことができます。
.sp
.nf
SELECT distributors.* WHERE distributors.name = 'Westward';

 did | name
-----+----------
 108 | Westward
  
.sp
.fi
これは暗黙の FROM アイテムが、問い合わせで参照されるけれども FROM では記述されないそれぞれのテーブルに追加されるので、動作します。これは便利な省略形ですが、間違って使いやすいです。 例えば、次の問い合わせ
.sp
.nf
SELECT distributors.* FROM distributors d;
  
.sp
.fi
はおそらく間違いです。 ユーザは
.sp
.nf
SELECT d.* FROM distributors d;
  
.sp
.fi
を意味していて、実際に得られる下記のような制約のない結合
.sp
.nf
SELECT distributors.* FROM distributors d, distributors distributors;
  
.sp
.fi
を意味していたわけではないでしょう。このような間違いの発見を助けるために PostgreSQL 7.1 とそれ以降では、もし暗黙の FROM 機能が明示的な FROM 句も持つ問い合わせで使われる場合警告を出します。
.PP
テーブル関数機能は、PostgreSQL の拡張です。
.SS "SQL92"
.PP
.SS "SELECT 句"
.PP
SQL92 標準では、オプションのキーワードAS はただのノイズなので、意味に影響することなく省略することが可能です。PostgreSQLパーサは出力列の名前を変更する際にこのキーワードを要求します。 なぜなら型の拡張機能を考えるとこのコンテキストでは構文解析の不明瞭さにつながるからです。しかし、FROM アイテムではAS はオプションです。
.PP
DISTINCT ON 文は SQL92 の一部ではありません。LIMIT も OFFSET もそうです。
.PP
SQL92 では ORDER BY 句は結果の列名か順番の数のみを使うことができ、GROUP BY 句は入力列名のみを使うことができます。PostgreSQL はこれらの句 がそれぞれ他の選択も認めるように拡張します(しかしもし不明瞭さがある場合は標準の解釈を使います)。PostgreSQL はどちらの句も任意の式を指定するよう認めています。式で使われる名前は常に結果の列名ではなく入力列名として見なされることに注意してください。
.SS "UNION/INTERSECT/EXCEPT 句"
.PP
SQL92 の UNION/INTERSECT/EXCEPT の構文では CORRESPONDING BY オプションを追加することができます。
.sp
.nf
 
\fItable_query\fR UNION [ALL]
    [CORRESPONDING [BY (\fIcolumn\fR [,...])]]
    \fItable_query\fR
     
.sp
.fi
.PP
CORRESPONDING BY 句は PostgreSQLではサポートされていません。
