.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ABORT" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
ABORT \- 現在のトランザクションのアボート
.SH SYNOPSIS
.sp
.nf
ABORT [ WORK | TRANSACTION ]
  
.sp
.fi
.SS "入力"
.PP
ありません。
.SS "出力"
.PP
.TP
\fBROLLBACK\fR
成功した時に返されるメッセージです。
.TP
\fBWARNING: ROLLBACK: no transaction in progress\fR
現在進行中のトランザクションが何もない場合です。
.PP
.SH "説明"
.PP
\fBABORT\fR は現在のトランザクションをロールバックし、そのトランザクションで行われたすべての更新を廃棄します。このコマンドは SQL92 の \fBROLLBACK\fR コマンドの動作と同一であり、歴史的な理由のためだけに存在しています。
.SS "注釈"
.PP
トランザクションを正常に終了させる場合は \fBCOMMIT\fR を使用してください。
.SH "使用方法"
.PP
すべての変更をアボートします。
.sp
.nf
ABORT WORK;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
このコマンドは歴史的な理由で存在する PostgreSQLの拡張です。SQL92 の\fBROLLBACK\fR コマンドがこれと等価なコマンドです。
