.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "TRUNCATE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
TRUNCATE \- テーブルの空化
.SH SYNOPSIS
.sp
.nf
TRUNCATE [ TABLE ] \fIname\fR
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
空にするテーブルの名前です (スキーマ修飾名でも可)。
.PP
.SS "出力"
.PP
.TP
\fBTRUNCATE TABLE\fR
テーブルを正常に空にできた場合に返されるメッセージです。
.PP
.SH "説明"
.PP
\fBTRUNCATE\fR はテーブルから全ての行を素早く削除します。これは、条件指定の無い \fBDELETE\fR コマンドと同様の機能ですが、実際にはテーブルをスキャンしないので、このコマンドの方が高速です。大きなテーブルの場合、このコマンドは最も効率的です。
.PP
\fBTRUNCATE\fR をトランザクションブロック (\fBBEGIN\fR と \fBCOMMIT\fR の組合せ) 内で実行することはできません。 これはロールバックさせる方法がないからです。
.SH "使用方法"
.PP
下記のコマンドは bigtable テーブルを空にします。
.sp
.nf
TRUNCATE TABLE bigtable;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には \fBTRUNCATE\fR はありません。
