.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP OPERATOR" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP OPERATOR \- ユーザ定義演算子の削除
.SH SYNOPSIS
.sp
.nf
DROP OPERATOR \fIid\fR ( \fIlefttype\fR | NONE , \fIrighttype\fR | NONE ) [ CASCADE | RESTRICT ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIid\fB\fR
既存の演算子の識別子です (スキーマ修飾名でも可)。
.TP
\fB\fIlefttype\fB\fR
演算子の左側の引数のデータ型です。左に引数がない場合は、NONE と記述してください。
.TP
\fB\fIrighttype\fB\fR
演算子の右側の引数のデータ型です。右に引数がない場合は、NONE と記述してください。
.TP
\fBCASCADE\fR
その演算子に依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、その演算子の削除要求を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP OPERATOR\fR
コマンドが正常に実行された場合に返されるメッセージです。
.TP
\fBERROR: RemoveOperator: binary operator '\fIoper\fB' taking '\fIlefttype\fB' and '\fIrighttype\fB' does not exist\fR
このメッセージは、指定された二項演算子が存在しない場合に出力されます。
.TP
\fBERROR: RemoveOperator: left unary operator '\fIoper\fB' taking '\fIlefttype\fB' does not exist\fR
このメッセージは、指定された左単項演算子が存在しない場合に出力されます。
.TP
\fBERROR: RemoveOperator: right unary operator '\fIoper\fB' taking '\fIrighttype\fB' does not exist\fR
このメッセージは、指定された右単項演算子が存在しない場合に出力されます。
.PP
.SH "説明"
.PP
\fBDROP OPERATOR\fR を実行すると、データベースから既存の演算子を削除できます。 このコマンドを実行するには、演算子の所有者でなければなりません。
.PP
左/右単項演算子の左/右のデータ型には、それぞれ NONE と指定する必要があります。
.SS "注釈"
.PP
\fBDROP OPERATOR\fR 文は、PostgreSQL の言語拡張です。
.PP
演算子の作成方法に関する情報については、CREATE OPERATOR [\fBcreate_operator\fR(l)] を参照して下さい。
.SH "使用方法"
.PP
int4 用の a^n という巾乗演算子を削除するには、次のようにします。
.sp
.nf
DROP OPERATOR ^ (int4, int4);
   
.sp
.fi
.PP
\fBboolean\fR 型の左単項否定演算子 (! b) を削除するには、次のようにします。
.sp
.nf
DROP OPERATOR ! (none, bool);
   
.sp
.fi
.PP
int4 型の右単項階乗演算子 (i !) を削除するには、次のようにします。
.sp
.nf
DROP OPERATOR ! (int4, none);
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
SQL92 には \fBDROP OPERATOR\fR はありません。
