.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP SCHEMA" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP SCHEMA \- スキーマの削除
.SH SYNOPSIS
.sp
.nf
DROP SCHEMA \fIname\fR [, ...] [ CASCADE | RESTRICT ]

  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
スキーマの名前です。
.TP
\fBCASCADE\fR
スキーマに含まれるオブジェクト (テーブル、関数など) を自動的に削除します。
.TP
\fBRESTRICT\fR
スキーマにオブジェクトが含まれている場合は、そのスキーマの削除を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP SCHEMA\fR
スキーマの削除に成功すると返されるメッセージです。
.TP
\fBERROR: Schema "\fIname\fB" does not exist\fR
このメッセージは、指定したスキーマが存在しない場合に出されます。
.PP
.SH "説明"
.PP
\fBDROP SCHEMA\fR はデータベースからスキーマを削除します。
.PP
スキーマを削除できるのは、所有者またはスーパーユーザのみです。 所有者は、スキーマ内に所有していないオブジェクトが含まれている場合でも、そのスキーマ (およびそこに含まれるすべてのオブジェクト) を削除できます。
.SS "注釈"
.PP
スキーマの作成方法に関する情報については \fBCREATE SCHEMA\fR を参照して下さい。
.SH "使用方法"
.PP
データベースからスキーマ mystuff、およびそこに含まれるすべてのものをデータベースから削除するには以下のようにします。
.sp
.nf
DROP SCHEMA mystuff CASCADE;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
\fBDROP SCHEMA\fR は、SQL92 では 1 度のコマンド実行につき 1 つのスキーマしか削除できないという点を除き、SQL92 と完全に互換性があります。
