.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP TYPE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP TYPE \- ユーザ定義のデータ型の削除
.SH SYNOPSIS
.sp
.nf
DROP TYPE \fItypename\fR [, ...] [ CASCADE | RESTRICT ]

  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fItypename\fB\fR
既存のデータ型の名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
削除するデータ型に依存するオブジェクト (テーブルの列、関数、演算子など) を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合に、このデータ型の削除を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP TYPE\fR
コマンドが正常に実行された場合に返されるメッセージです。
.TP
\fBERROR: RemoveType: type '\fItypename\fB' does not exist\fR
このメッセージは、指定されたデータ型が存在しない場合に返されます。
.PP
.SH "説明"
.PP
\fBDROP TYPE\fR はシステムカタログからユーザ定義型を削除します。
.PP
データ型を削除できるのは、その所有者のみです。
.SH "例"
.PP
\fBbox\fR データ型を削除するには以下のようにします。
.sp
.nf
DROP TYPE box;
.sp
.fi
.SH "互換性"
.PP
\fBCREATE TYPE\fR コマンドと PostgreSQL のデータ型拡張機構は SQL99 とは異なる点に注意して下さい。
.SH "関連項目"
CREATE TYPE [\fBcreate_type\fR(l)]
