.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE CONSTRAINT TRIGGER" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE CONSTRAINT TRIGGER \- 新しい制約トリガの定義
.SH SYNOPSIS
.sp
.nf
CREATE CONSTRAINT TRIGGER \fIname\fR
    AFTER \fIevents\fR ON
    \fIrelation\fR \fIconstraint\fR \fIattributes\fR
    FOR EACH ROW EXECUTE PROCEDURE \fIfunc\fR '(' \fIargs\fR ')'
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
制約トリガの名前です。
.TP
\fB\fIevents\fB\fR
このトリガが実行されるイベントの種類です。
.TP
\fB\fIrelation\fB\fR
トリガイベントが発生するリレーションの名前です (スキーマ修飾名の場合もあります)。
.TP
\fB\fIconstraint\fB\fR
制約の実仕様です。
.TP
\fB\fIattributes\fB\fR
制約属性です。
.TP
\fB\fIfunc\fB(\fIargs\fB)\fR
トリガの処理部分として呼び出される関数です。
.PP
.SS "出力"
.PP
.TP
\fBCREATE TRIGGER\fR
成功した時に返されるメッセージです。
.PP
.SH "説明"
.PP
\fBCREATE CONSTRAINT TRIGGER\fR は、\fBCREATE/ALTER TABLE\fR の中で、または \fBpg_dump\fR によって使用され、参照整合性用の特殊なトリガを作成します。
.PP
一般的な使用を意図したものではありません。
