.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "REVOKE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
REVOKE \- アクセス権限の取り上げ
.SH SYNOPSIS
.sp
.nf
REVOKE { { SELECT | INSERT | UPDATE | DELETE | RULE | REFERENCES | TRIGGER }
    [,...] | ALL [ PRIVILEGES ] }
    ON [ TABLE ] \fItablename\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]

REVOKE { { CREATE | TEMPORARY | TEMP } [,...] | ALL [ PRIVILEGES ] }
    ON DATABASE \fIdbname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]

REVOKE { EXECUTE | ALL [ PRIVILEGES ] }
    ON FUNCTION \fIfuncname\fR ([\fItype\fR, ...]) [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]

REVOKE { USAGE | ALL [ PRIVILEGES ] }
    ON LANGUAGE \fIlangname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]

REVOKE { { CREATE | USAGE } [,...] | ALL [ PRIVILEGES ] }
    ON SCHEMA \fIschemaname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
.sp
.fi
.SH "説明"
.PP
オブジェクトの作成者は \fBREVOKE\fR を使用して、1つ以上のユーザあるいはユーザグループから、以前に与えられた権限を取り上げることができます。PUBLIC というキーワードは、暗黙的に定義された、すべてのユーザからなるグループを意味します。
.PP
個々のユーザはすべて、ユーザに直接許可された権限、ユーザが現在属しているグループに許可された権限、そして、PUBLIC に許可された権限を合わせた権限を持っていることに注意して下さい。従って、例えば、PUBLIC から SELECT 権限を取り上げることは、必ずしもそのオブジェクトに対する SELECT 権限をすべてのユーザが失うことを意味しません。直接、あるいは、グループ経由で許可されたユーザは、その権限を持ち続けます。
.PP
権限の種類の意味については、GRANT [\fBgrant\fR(l)] コマンドの説明を参照して下さい。
.SH "注釈"
.PP
\fBpsql\fR(1) の \fB\\z\fR コマンドを使用して、存在するオブジェクトに対し与えられた権限を表示することができます。この書式についての情報も GRANT [\fBgrant\fR(l)] を参照して下さい。
.SH "例"
.PP
films テーブルから、public に与えた挿入権限を取り上げます。
.sp
.nf
REVOKE INSERT ON films FROM PUBLIC;
.sp
.fi
.PP
kinds ビューから、manuel に与えたすべての権限を取り上げます。
.sp
.nf
  
REVOKE ALL PRIVILEGES ON kinds FROM manuel;
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
GRANT [\fBgrant\fR(l)] コマンドの互換性についての注釈は、\fBREVOKE\fR にも当てはまります。構文の要約を以下に示します。
.sp
.nf
REVOKE [ GRANT OPTION FOR ] { SELECT | INSERT | UPDATE | DELETE | REFERENCES }
    ON \fIobject\fR [ ( \fIcolumn\fR [, ...] ) ]
    FROM { PUBLIC | \fIusername\fR [, ...] }
    { RESTRICT | CASCADE }
.sp
.fi
.PP
user1 が user2 に WITH GRANT OPTION 権限を与え、そして、user2 が user3 に同じ権限を与えた場合、user1 はCASCADE キーワードを使用して、数珠繋ぎに権限を取り上げることができます。user1 が WITH GRANT OPTION 権限を user2 に与え、そして、user2 が user3 に同じ権限を付与した場合、user1 は RESTRICT キーワードを付けると、権限の取り上げに失敗します。
.SH "関連項目"
.PP
GRANT [\fBgrant\fR(l)]
