.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP DOMAIN" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP DOMAIN \- ユーザ定義ドメインの削除
.SH SYNOPSIS
.sp
.nf
DROP DOMAIN \fIdomainname\fR [, ...]  [ CASCADE | RESTRICT ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIdomainname\fB\fR
既存のドメインの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
ドメインに依存するオブジェクト (テーブルの列など) を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、そのドメインの削除要求を拒否します。これがデフォルトです。
.PP
.SS "出力"
.PP
.TP
\fBDROP DOMAIN\fR
コマンドが正常に実行された場合に返されるメッセージです。
.TP
\fBERROR: RemoveDomain: type '\fIdomainname\fB' does not exist\fR
このメッセージは、指定したドメイン (または型) が存在しなかった場合に表示されます。
.PP
.SH "説明"
.PP
\fBDROP DOMAIN\fR を実行すると、システムカタログからユーザドメインを削除することができます。
.PP
ドメインの所有者のみが、そのドメインを削除できます。
.SH "例"
.PP
\fBbox\fR ドメインを削除するには、以下のようにします。
.sp
.nf
DROP DOMAIN box;
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
.SH "関連項目"
   CREATE DOMAIN   [\fBcreate_domain\fR(l)]
