.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP DATABASE" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP DATABASE \- データベースの削除
.SH SYNOPSIS
.sp
.nf
DROP DATABASE \fIname\fR
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIname\fB\fR
削除する既存のデータベース名です。
.PP
.SS "出力"
.PP
.TP
\fBDROP DATABASE\fR
コマンドの実行に成功した場合に返されるメッセージです。
.TP
\fBDROP DATABASE: cannot be executed on the currently open database\fR
削除しようとするデータベースに接続はできません。代わりに、template1 や他のデータベースに接続してからこのコマンドを再実行して下さい。
.TP
\fBDROP DATABASE: may not be called in a transaction block\fR
このコマンドを呼び出す前に、実行中のトランザクションを完了させる必要があります。
.PP
.SH "説明"
.PP
\fBDROP DATABASE\fRは、カタログから既存のデータベースの項目を削除し、データを保存していたディレクトリの削除を行ないます。データベースの所有者(通常はデータベースの作成者)のみがこのコマンドを実行することができます。
.PP
\fBDROP DATABASE\fR は元に戻すことができません。注意して使用して下さい。
.SS "注釈"
.PP
対象とするデータベースに接続している場合、このコマンドを実行することができません。したがって、このコマンドのラッパーである dropdb [\fBdropdb\fR(1)]シェルスクリプトを使用する方が便利かもしれません。
.PP
データベースの作成方法に関する詳細はCREATE DATABASE [\fBcreate_database\fR(l)]を参照して下さい。
.SH "互換性"
.SS "SQL92"
.PP
\fBDROP DATABASE\fR文は PostgreSQLの言語拡張です。SQL92にはこのようなコマンドはありません。
