.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "RESET" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
RESET \- 実行時パラメータの値をデフォルト値に戻す
.SH SYNOPSIS
.sp
.nf
RESET \fIvariable\fR
  
.sp
.fi
.sp
.nf
RESET ALL
  
.sp
.fi
.SS "入力"
.PP
.TP
\fB\fIvariable\fB\fR
実行時パラメータ名。そのリストはSET [\fBset\fR(l)]を参照して下さい。
.TP
\fBALL\fR
設定可能なすべての実行時パラメータをデフォルト値に戻します。
.PP
.SH "説明"
.PP
\fBRESET\fR は実行時パラメータをデフォルト値に戻します。詳細は SET [\fBset\fR(l)]を見て下さい。 \fBRESET\fR は下記のように記述することもできます。
.sp
.nf
SET \fIvariable\fR TO DEFAULT
   
.sp
.fi
デフォルト値は、現行セッション内で \fBSET\fR コマンドが発行されない場合に変数に代入される値として定義されます。 この値の実際のソースは、コンパイル済みのデフォルトにすることができます。 すなわち postmaster の設定ファイルかコマンドラインスイッチの、データベース毎あるいはユーザ毎のデフォルト設定です。詳細は \fI管理者ガイ ド\fRを参照して下さい。
.PP
\fBRESET\fR トランザクションの振る舞いについて詳しくはマニュアルの \fBSET\fR のページを参照してください。
.SH "診断"
.PP
SET [\fBset\fR(l)] コマンドの部分を見て下さい。
.SH "例"
.PP
DateStyle をデフォルト値に設定します。
.sp
.nf
RESET DateStyle;
.sp
.fi
.PP
geqo をデフォルト値に設定します。
.sp
.nf
   
RESET GEQO;
.sp
.fi
.SH "互換性"
.PP
\fBRESET\fR は PostgreSQLの拡張です。
