.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "END" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
END \- 現在のトランザクションのコミット
.SH SYNOPSIS
.sp
.nf
END [ WORK | TRANSACTION ]
  
.sp
.fi
.SS "入力"
.PP
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
省略可能なキーワード。これらは何も効果がありません。
.PP
.SS "出力"
.PP
.TP
\fBCOMMIT\fR
トランザクションが正常にコミットされた場合に返されるメッセージです。
.TP
\fBWARNING: COMMIT: no transaction in progress\fR
実行中のトランザクションが存在しない場合表示されます。
.PP
.SH "説明"
.PP
\fBEND\fRコマンドはPostgreSQLの言語拡張です。SQL92互換の[XRef to SQL-COMMIT-TITLE].と同義です。
.SS "注釈"
.PP
WORK及びTRANSACTIONキーワードには意味がなく、省略可能です。
.PP
トランザクションのアボートには、 [XRef to SQL-ROLLBACK-TITLE] を使用して下さい。
.SH "使用方法"
.PP
下記のコマンドは、全ての変更を保存します。
.sp
.nf
END WORK;
   
.sp
.fi
.SH "互換性"
.SS "SQL92"
.PP
\fBEND\fRはPostgreSQL の拡張であり、これは、[XRef to SQL-COMMIT-TITLE]と機能的に同じものです。
