.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP USER" "" "2003-08-02" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP USER \- データベースユーザアカウントの削除
.SH SYNOPSIS
.sp
.nf
DROP USER \fIname\fR
.sp
.fi
.SH "説明"
.PP
\fBDROP USER\fR は指定されたユーザをデータベースから削除します。そのユーザが所有するテーブル、ビュー、その他のオブジェクトは削除しません。 ユーザがデータベースを所有している場合は、エラーが出されます。
.SS "パラメータ"
.PP
.TP
\fB\fIname\fB\fR
既存のユーザの名前です。
.PP
.SH "診断"
.PP
.TP
\fBDROP USER\fR
このメッセージはユーザの削除に成功した場合に返されます。
.TP
\fBERROR: DROP USER: user "\fIname\fB" does not exist\fR
このメッセージはユーザ名が存在しなかった場合に表示されます。
.TP
\fBDROP USER: user "\fIname\fB" owns database "\fIname\fB", cannot be removed\fR
先にデータベースを削除するか、所有者を変更する必要があります。
.PP
.SH "注釈"
.PP
新しいユーザを追加するには CREATE USER [\fBcreate_user\fR(l)] を、ユーザの属性を変更するには ALTER USER [\fBalter_user\fR(l)] を使用してください。 PostgreSQL には、このコマンドと同じ機能を持つ (実際は、このコマンドを呼び出しています) プログラム dropuser [\fBdropuser\fR(1)] があり、コマンドシェルから実行することができます。
.SH "例"
.PP
ユーザアカウントを削除します。
.sp
.nf
DROP USER jonathan;
.sp
.fi
.SH "互換性"
.PP
\fBDROP USER\fR 文は PostgreSQL の拡張です。 SQL 標準では、ユーザの定義は実装に任されています。
.SH "関連項目"
CREATE USER [\fBcreate_user\fR(l)], ALTER USER [\fBalter_user\fR(l)], \fBdropuser\fR(1)
